from ... pyaz_utils import call_az
from . import blob_inventory_policy, blob_service_properties, encryption_scope, file_service_properties, hns_migration, keys, management_policy, network_rule, or_policy, private_endpoint_connection, private_link_resource


def check_name(name):
    '''
    Check that the storage account name is valid and is not already in use.
    '''
    return call_az("az storage account check-name", locals())


def create(name, resource_group, access_tier=None, action=None, allow_blob_public_access=None, allow_cross_tenant_replication=None, allow_protected_append_writes=None, allow_shared_key_access=None, assign_identity=None, azure_storage_sid=None, bypass=None, custom_domain=None, default_action=None, default_share_permission=None, domain_guid=None, domain_name=None, domain_sid=None, edge_zone=None, enable_alw=None, enable_files_aadds=None, enable_files_adds=None, enable_hierarchical_namespace=None, enable_large_file_share=None, enable_nfs_v3=None, encryption_key_name=None, encryption_key_source=None, encryption_key_type_for_queue=None, encryption_key_type_for_table=None, encryption_key_vault=None, encryption_key_version=None, encryption_services=None, forest_name=None, https_only=None, identity_type=None, immutability_period_in_days=None, immutability_state=None, key_expiration_period_in_days=None, key_vault_user_identity_id=None, kind=None, location=None, min_tls_version=None, net_bios_domain_name=None, public_network_access=None, publish_internet_endpoints=None, publish_microsoft_endpoints=None, require_infrastructure_encryption=None, routing_choice=None, sas_expiration_period=None, sku=None, subnet=None, tags=None, user_identity_id=None, vnet_name=None):
    '''
    Create a storage account.
    '''
    return call_az("az storage account create", locals())


def delete(name, resource_group=None, yes=None):
    '''
    Delete a storage account.
    '''
    return call_az("az storage account delete", locals())


def show(name, expand=None, resource_group=None):
    '''
    Show storage account properties.
    '''
    return call_az("az storage account show", locals())


def list(resource_group=None):
    '''
    List storage accounts.
    '''
    return call_az("az storage account list", locals())


def show_usage(location):
    '''
    Show the current count and limit of the storage accounts under the subscription.
    '''
    return call_az("az storage account show-usage", locals())


def show_connection_string(name, blob_endpoint=None, file_endpoint=None, key=None, protocol=None, queue_endpoint=None, resource_group=None, sas_token=None, table_endpoint=None):
    '''
    Get the connection string for a storage account.
    '''
    return call_az("az storage account show-connection-string", locals())


def update(name, access_tier=None, add=None, allow_blob_public_access=None, allow_cross_tenant_replication=None, allow_protected_append_writes=None, allow_shared_key_access=None, assign_identity=None, azure_storage_sid=None, bypass=None, custom_domain=None, default_action=None, default_share_permission=None, domain_guid=None, domain_name=None, domain_sid=None, enable_files_aadds=None, enable_files_adds=None, enable_large_file_share=None, encryption_key_name=None, encryption_key_source=None, encryption_key_vault=None, encryption_key_version=None, encryption_services=None, force_string=None, forest_name=None, https_only=None, identity_type=None, immutability_period_in_days=None, immutability_state=None, key_expiration_period_in_days=None, key_vault_user_identity_id=None, min_tls_version=None, net_bios_domain_name=None, public_network_access=None, publish_internet_endpoints=None, publish_microsoft_endpoints=None, remove=None, resource_group=None, routing_choice=None, sas_expiration_period=None, set=None, sku=None, tags=None, use_subdomain=None, user_identity_id=None):
    '''
    Update the properties of a storage account.
    '''
    return call_az("az storage account update", locals())


def failover(name, no_wait=None, resource_group=None, yes=None):
    '''
    Failover request can be triggered for a storage account in case of availability issues.
    '''
    return call_az("az storage account failover", locals())


def revoke_delegation_keys(name, resource_group=None):
    '''
    Revoke all user delegation keys for a storage account.
    '''
    return call_az("az storage account revoke-delegation-keys", locals())


def generate_sas(expiry, permissions, resource_types, services, account_key=None, account_name=None, connection_string=None, https_only=None, ip=None, start=None):
    '''
    Generate a shared access signature for the storage account.
    '''
    return call_az("az storage account generate-sas", locals())




from .... pyaz_utils import call_az

def delete(id=None, name=None, namespace_name=None, resource_group=None, yes=None):
    '''
    Delete a private endpoint connection request for eventhubs namespace.
    '''
    return call_az("az eventhubs namespace private-endpoint-connection delete", locals())


def show(id=None, name=None, namespace_name=None, resource_group=None):
    '''
    Show details of a private endpoint connection request for eventhubs namespace.
    '''
    return call_az("az eventhubs namespace private-endpoint-connection show", locals())


def list(namespace_name, resource_group):
    return call_az("az eventhubs namespace private-endpoint-connection list", locals())


def approve(description=None, id=None, name=None, namespace_name=None, resource_group=None):
    '''
    Approve a private endpoint connection request for eventhubs namesapce.
    '''
    return call_az("az eventhubs namespace private-endpoint-connection approve", locals())


def reject(description=None, id=None, name=None, namespace_name=None, resource_group=None):
    '''
    Reject a private endpoint connection request for eventhubs namespace.
    '''
    return call_az("az eventhubs namespace private-endpoint-connection reject", locals())




from .... pyaz_utils import call_az

def create(name, resource_group, server_name, subnet, ignore_missing_endpoint=None, vnet_name=None):
    '''
    Create a virtual network rule to allows access to a MariaDB server.
    '''
    return call_az("az mariadb server vnet-rule create", locals())


def delete(name, resource_group, server_name):
    return call_az("az mariadb server vnet-rule delete", locals())


def show(name, resource_group, server_name):
    return call_az("az mariadb server vnet-rule show", locals())


def list(resource_group, server_name):
    return call_az("az mariadb server vnet-rule list", locals())


def update(name, resource_group, server_name, subnet, add=None, force_string=None, ignore_missing_endpoint=None, remove=None, set=None, vnet_name=None):
    '''
    Update a virtual network rule.
    '''
    return call_az("az mariadb server vnet-rule update", locals())




from ... pyaz_utils import call_az

def list():
    '''
    List supported regulatory compliance standards details and state results.
    '''
    return call_az("az security regulatory-compliance-standards list", locals())


def show(name):
    '''
    Shows a regulatory compliance details state for selected standard.
    '''
    return call_az("az security regulatory-compliance-standards show", locals())




from .... pyaz_utils import call_az

def list(name, resource_group):
    '''
    List deployment operations at resource group.
    '''
    return call_az("az deployment operation group list", locals())


def show(name, operation_ids, resource_group):
    '''
    Show a deployment operation at resource group.
    '''
    return call_az("az deployment operation group show", locals())




from .... pyaz_utils import call_az

def list(account_name, profile_name):
    '''
    List the invoice sections that a user has access to. The operation is supported only for billing accounts with agreement type Microsoft Customer Agreement.
    '''
    return call_az("az billing invoice section list", locals())


def show(account_name, name, profile_name):
    '''
    Get an invoice section by its ID. The operation is supported only for billing accounts with agreement type Microsoft Customer Agreement.
    '''
    return call_az("az billing invoice section show", locals())


def create(account_name, name, profile_name, display_name=None, labels=None, no_wait=None):
    '''
    Creates or updates an invoice section. The operation is supported only for billing accounts with agreement type Microsoft Customer Agreement.
    '''
    return call_az("az billing invoice section create", locals())


def update(account_name, name, profile_name, display_name=None, labels=None, no_wait=None):
    '''
    Creates or updates an invoice section. The operation is supported only for billing accounts with agreement type Microsoft Customer Agreement.
    '''
    return call_az("az billing invoice section update", locals())


def wait(account_name, name, profile_name, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the billing invoice section is met.
    '''
    return call_az("az billing invoice section wait", locals())




from ..... pyaz_utils import call_az

def create(category, display_name, name, resource_group, saved_query, workspace_name, func_alias=None, func_param=None, tags=None):
    '''
    Create a saved search for a given workspace.
    '''
    return call_az("az monitor log-analytics workspace saved-search create", locals())


def update(name, resource_group, workspace_name, add=None, category=None, display_name=None, force_string=None, func_alias=None, func_param=None, remove=None, saved_query=None, set=None, tags=None):
    '''
    Update a saved search for a given workspace.
    '''
    return call_az("az monitor log-analytics workspace saved-search update", locals())


def delete(name, resource_group, workspace_name, yes=None):
    '''
    Delete a saved search for a given workspace.
    '''
    return call_az("az monitor log-analytics workspace saved-search delete", locals())


def show(name, resource_group, workspace_name):
    '''
    Show a saved search for a given workspace.
    '''
    return call_az("az monitor log-analytics workspace saved-search show", locals())


def list(resource_group, workspace_name):
    '''
    List all saved searches for a given workspace.
    '''
    return call_az("az monitor log-analytics workspace saved-search list", locals())




from ..... pyaz_utils import call_az

def show(name, resource_group, zone_name, record_type=None):
    '''
    Get the details of a CNAME record set.
    '''
    return call_az("az network private-dns record-set cname show", locals())


def delete(name, resource_group, zone_name, if_match=None, record_type=None, yes=None):
    '''
    Delete a CNAME record set and its associated record.
    '''
    return call_az("az network private-dns record-set cname delete", locals())


def list(resource_group, zone_name, record_type=None):
    '''
    List the CNAME record set in a zone.
    '''
    return call_az("az network private-dns record-set cname list", locals())


def create(name, resource_group, zone_name, metadata=None, record_type=None, ttl=None):
    '''
    Create an empty CNAME record set.
    '''
    return call_az("az network private-dns record-set cname create", locals())


def set_record(cname, record_set_name, resource_group, zone_name):
    '''
    Set the value of a CNAME record.
    '''
    return call_az("az network private-dns record-set cname set-record", locals())


def remove_record(cname, record_set_name, resource_group, zone_name, keep_empty_record_set=None):
    '''
    Remove a CNAME record from its record set.
    '''
    return call_az("az network private-dns record-set cname remove-record", locals())


def update(name, resource_group, zone_name, add=None, force_string=None, if_match=None, metadata=None, record_type=None, remove=None, set=None):
    '''
    Update a CNAME record set.
    '''
    return call_az("az network private-dns record-set cname update", locals())




from .... pyaz_utils import call_az

def assign(name, resource_group=None, role=None, scopes=None, system_assigned=None, user_assigned=None):
    '''
    Assign managed identities to an IoT Hub
    '''
    return call_az("az iot hub identity assign", locals())


def show(name, resource_group=None):
    '''
    Show the identity properties of an IoT Hub
    '''
    return call_az("az iot hub identity show", locals())


def remove(name, resource_group=None, system_assigned=None, user_assigned=None):
    '''
    Remove managed identities from an IoT Hub
    '''
    return call_az("az iot hub identity remove", locals())




from ... pyaz_utils import call_az
from . import connection


def create(lb_frontend_ip_configs, name, resource_group, subnet, auto_approval=None, edge_zone=None, enable_proxy_protocol=None, fqdns=None, lb_name=None, location=None, private_ip_address=None, private_ip_address_version=None, private_ip_allocation_method=None, public_ip_address=None, tags=None, visibility=None, vnet_name=None):
    '''
    Create a private link service.
    '''
    return call_az("az network private-link-service create", locals())


def delete(name, resource_group):
    '''
    Delete a private link service.
    '''
    return call_az("az network private-link-service delete", locals())


def list(resource_group=None):
    '''
    List private link services.
    '''
    return call_az("az network private-link-service list", locals())


def show(name, resource_group, expand=None):
    '''
    Get the details of a private link service.
    '''
    return call_az("az network private-link-service show", locals())


def update(name, resource_group, add=None, auto_approval=None, enable_proxy_protocol=None, force_string=None, fqdns=None, lb_frontend_ip_configs=None, lb_name=None, remove=None, set=None, tags=None, visibility=None):
    '''
    Update a private link service.
    '''
    return call_az("az network private-link-service update", locals())




from .... pyaz_utils import call_az

def list(gateway_name, resource_group):
    '''
    List frontend ports.
    '''
    return call_az("az network application-gateway frontend-port list", locals())


def show(gateway_name, name, resource_group):
    '''
    Get the details of a frontend port.
    '''
    return call_az("az network application-gateway frontend-port show", locals())


def delete(gateway_name, name, resource_group, no_wait=None):
    '''
    Delete a frontend port.
    '''
    return call_az("az network application-gateway frontend-port delete", locals())


def create(gateway_name, name, port, resource_group, no_wait=None):
    '''
    Create a frontend port.
    '''
    return call_az("az network application-gateway frontend-port create", locals())


def update(gateway_name, name, resource_group, add=None, force_string=None, no_wait=None, port=None, remove=None, set=None):
    '''
    Update a frontend port.
    '''
    return call_az("az network application-gateway frontend-port update", locals())




from ... pyaz_utils import call_az

def create(certificate_file, thumbprint, account_endpoint=None, account_key=None, account_name=None, password=None):
    '''
    Add a certificate to a Batch account.
    '''
    return call_az("az batch certificate create", locals())


def delete(thumbprint, abort=None, account_endpoint=None, account_key=None, account_name=None, yes=None):
    '''
    Delete a certificate from a Batch account.
    '''
    return call_az("az batch certificate delete", locals())


def show(thumbprint, account_endpoint=None, account_key=None, account_name=None, select=None):
    return call_az("az batch certificate show", locals())


def list(account_endpoint=None, account_key=None, account_name=None, filter=None, select=None):
    return call_az("az batch certificate list", locals())




from .... pyaz_utils import call_az

def assign(name, resource_group, system_assigned=None, user_assigned=None):
    '''
    Assign Identities to Recovery Services vault.
    '''
    return call_az("az backup vault identity assign", locals())


def remove(name, resource_group, system_assigned=None, user_assigned=None):
    '''
    Remove Identities of Recovery Services vault.
    '''
    return call_az("az backup vault identity remove", locals())


def show(name, resource_group):
    '''
    Show Identities of Recovery Services vault.
    '''
    return call_az("az backup vault identity show", locals())




from .... pyaz_utils import call_az

def create(cluster_name, days, resource_group, time, workernode_count, no_wait=None):
    '''
    Add a new schedule condition.
    '''
    return call_az("az hdinsight autoscale condition create", locals())


def update(cluster_name, index, resource_group, days=None, no_wait=None, time=None, workernode_count=None):
    '''
    Update a schedule condition.
    '''
    return call_az("az hdinsight autoscale condition update", locals())


def list(cluster_name, resource_group):
    '''
    List all schedule conditions.
    '''
    return call_az("az hdinsight autoscale condition list", locals())


def delete(cluster_name, index, resource_group, no_wait=None, yes=None):
    '''
    Delete schedule condition.
    '''
    return call_az("az hdinsight autoscale condition delete", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until an operation is complete.
    '''
    return call_az("az hdinsight autoscale condition wait", locals())




from ... pyaz_utils import call_az
from . import connection_monitor, flow_log, packet_capture, troubleshooting


def configure(locations, enabled=None, resource_group=None, tags=None):
    '''
    Configure the Network Watcher service for different regions.
    '''
    return call_az("az network watcher configure", locals())


def list():
    '''
    List Network Watchers.
    '''
    return call_az("az network watcher list", locals())


def test_ip_flow(direction, local, protocol, remote, vm, nic=None, resource_group=None):
    '''
    Test IP flow to/from a VM given the currently configured network security group rules.
    '''
    return call_az("az network watcher test-ip-flow", locals())


def test_connectivity(source_resource, dest_address=None, dest_port=None, dest_resource=None, headers=None, method=None, protocol=None, resource_group=None, source_port=None, valid_status_codes=None):
    '''
    Test if a connection can be established between a Virtual Machine and a given endpoint.
    '''
    return call_az("az network watcher test-connectivity", locals())


def show_next_hop(dest_ip, resource_group, source_ip, vm, nic=None):
    '''
    Get information on the 'next hop' of a VM.
    '''
    return call_az("az network watcher show-next-hop", locals())


def show_security_group_view(resource_group, vm):
    '''
    Get detailed security information on a VM for the currently configured network security group.
    '''
    return call_az("az network watcher show-security-group-view", locals())


def show_topology(location=None, resource_group=None, subnet=None, vnet=None):
    '''
    Get the network topology of a resource group, virtual network or subnet.
    '''
    return call_az("az network watcher show-topology", locals())


def run_configuration_diagnostic(resource, destination=None, direction=None, parent=None, port=None, protocol=None, queries=None, resource_group=None, resource_type=None, source=None):
    '''
    Run a configuration diagnostic on a target resource.
    '''
    return call_az("az network watcher run-configuration-diagnostic", locals())




from ... pyaz_utils import call_az

def list(registry, resource_group=None):
    '''
    List all of the regions for a geo-replicated Azure Container Registry.
    '''
    return call_az("az acr replication list", locals())


def create(location, registry, name=None, region_endpoint_enabled=None, resource_group=None, tags=None, zone_redundancy=None):
    '''
    Create a replicated region for an Azure Container Registry.
    '''
    return call_az("az acr replication create", locals())


def delete(name, registry, resource_group=None):
    '''
    Delete a replicated region from an Azure Container Registry.
    '''
    return call_az("az acr replication delete", locals())


def show(name, registry, resource_group=None):
    '''
    Get the details of a replicated region.
    '''
    return call_az("az acr replication show", locals())


def update(name, registry, add=None, force_string=None, region_endpoint_enabled=None, remove=None, resource_group=None, set=None, tags=None):
    '''
    Updates a replication.
    '''
    return call_az("az acr replication update", locals())




from ..... pyaz_utils import call_az

def create(account_name, body, resource_group, no_wait=None):
    '''
    Create a SQL role definition under an Azure Cosmos DB account.
    '''
    return call_az("az cosmosdb sql role definition create", locals())


def update(account_name, body, resource_group, no_wait=None):
    '''
    Update a SQL role definition under an Azure Cosmos DB account.
    '''
    return call_az("az cosmosdb sql role definition update", locals())


def exists(account_name, id, resource_group):
    '''
    Check if an Azure Cosmos DB role definition exists.
    '''
    return call_az("az cosmosdb sql role definition exists", locals())


def list(account_name, resource_group):
    '''
    List all SQL role definitions under an Azure Cosmos DB account.
    '''
    return call_az("az cosmosdb sql role definition list", locals())


def show(account_name, id, resource_group):
    '''
    Show the properties of a SQL role definition under an Azure Cosmos DB account.
    '''
    return call_az("az cosmosdb sql role definition show", locals())


def delete(account_name, id, resource_group, no_wait=None, yes=None):
    '''
    Delete a SQL role definition under an Azure Cosmos DB account.
    '''
    return call_az("az cosmosdb sql role definition delete", locals())


def wait(account_name, id, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Poll on a SQL role definition until a specific condition is met.
    '''
    return call_az("az cosmosdb sql role definition wait", locals())




from ... pyaz_utils import call_az

def create(end_ip, name, resource_group, rule_name, start_ip):
    '''
    Create a redis cache firewall rule.
    '''
    return call_az("az redis firewall-rules create", locals())


def update(end_ip, name, resource_group, rule_name, start_ip):
    '''
    Update a redis cache firewall rule.
    '''
    return call_az("az redis firewall-rules update", locals())


def delete(name, resource_group, rule_name):
    return call_az("az redis firewall-rules delete", locals())


def show(name, resource_group, rule_name):
    return call_az("az redis firewall-rules show", locals())


def list(name, resource_group):
    return call_az("az redis firewall-rules list", locals())




from .... pyaz_utils import call_az

def list(end_date, reservation_order_id, start_date, reservation_id=None):
    '''
    List the details of a reservation by order id or reservation id.
    '''
    return call_az("az consumption reservation detail list", locals())




from .... pyaz_utils import call_az

def list(api_id, resource_group, service_name):
    '''
    Lists all revisions of an API.
    '''
    return call_az("az apim api revision list", locals())


def create(api_id, api_revision, resource_group, service_name, api_revision_description=None):
    '''
    Create API revision.
    '''
    return call_az("az apim api revision create", locals())




from ... pyaz_utils import call_az

def list(location=None, resource_group=None):
    '''
    List security alerts.
    '''
    return call_az("az security alert list", locals())


def show(location, name, resource_group=None):
    '''
    Shows a security alert.
    '''
    return call_az("az security alert show", locals())


def update(location, name, status, resource_group=None):
    '''
    Updates a security alert status.
    '''
    return call_az("az security alert update", locals())




from ... pyaz_utils import call_az
from . import client_certificate


def list(resource_group=None):
    '''
    List managed clusters.
    '''
    return call_az("az sf managed-cluster list", locals())


def delete(cluster_name, resource_group):
    '''
    Delete a managed cluster.
    '''
    return call_az("az sf managed-cluster delete", locals())


def show(cluster_name, resource_group):
    '''
    Show the properties of an Azure Service Fabric managed cluster.
    '''
    return call_az("az sf managed-cluster show", locals())


def create(admin_password, cluster_name, resource_group, admin_user_name=None, client_cert_common_name=None, client_cert_is_admin=None, client_cert_issuer_thumbprint=None, client_cert_thumbprint=None, client_connection_port=None, cluster_code_version=None, cluster_upgrade_cadence=None, cluster_upgrade_mode=None, dns_name=None, gateway_connection_port=None, location=None, sku=None, tags=None):
    '''
    Delete a managed cluster.
    '''
    return call_az("az sf managed-cluster create", locals())


def update(cluster_name, resource_group, client_connection_port=None, dns_name=None, gateway_connection_port=None, tags=None):
    '''
    Update a managed cluster.
    '''
    return call_az("az sf managed-cluster update", locals())




from ... pyaz_utils import call_az
from . import deployment


def show(name, management_group=None, namespace=None, parent=None, resource=None, resource_group=None, resource_type=None):
    '''
    Show a resource policy remediation.
    '''
    return call_az("az policy remediation show", locals())


def list(management_group=None, namespace=None, parent=None, resource=None, resource_group=None, resource_type=None):
    '''
    List resource policy remediations.
    '''
    return call_az("az policy remediation list", locals())


def delete(name, management_group=None, namespace=None, parent=None, resource=None, resource_group=None, resource_type=None):
    '''
    Delete a resource policy remediation.
    '''
    return call_az("az policy remediation delete", locals())


def cancel(name, management_group=None, namespace=None, parent=None, resource=None, resource_group=None, resource_type=None):
    '''
    Cancel a resource policy remediation.
    '''
    return call_az("az policy remediation cancel", locals())


def create(name, policy_assignment, definition_reference_id=None, location_filters=None, management_group=None, namespace=None, parent=None, resource=None, resource_discovery_mode=None, resource_group=None, resource_type=None):
    '''
    Create a resource policy remediation.
    '''
    return call_az("az policy remediation create", locals())




from ... pyaz_utils import call_az

def create(authorizations, description, display_name, lock_level, name, resource_group, create_ui_definition=None, location=None, main_template=None, package_file_uri=None, tags=None):
    '''
    Create a managed application definition.
    '''
    return call_az("az managedapp definition create", locals())


def update(authorizations, description, display_name, lock_level, name, resource_group, create_ui_definition=None, location=None, main_template=None, package_file_uri=None, tags=None):
    '''
    Update a managed application definition.
    '''
    return call_az("az managedapp definition update", locals())


def delete(name, resource_group):
    '''
    Delete a managed application definition.
    '''
    return call_az("az managedapp definition delete", locals())


def show(name=None, resource_group=None):
    return call_az("az managedapp definition show", locals())


def list(resource_group):
    '''
    List managed application definitions.
    '''
    return call_az("az managedapp definition list", locals())




from ... pyaz_utils import call_az

def create(name, description=None, display_name=None, exemption_category=None, expires_on=None, metadata=None, policy_assignment=None, policy_definition_reference_ids=None, resource_group=None, scope=None):
    '''
    Create a policy exemption.
    '''
    return call_az("az policy exemption create", locals())


def delete(name, resource_group=None, scope=None):
    '''
    Delete a policy exemption.
    '''
    return call_az("az policy exemption delete", locals())


def list(disable_scope_strict_match=None, resource_group=None, scope=None):
    '''
    List policy exemptions.
    '''
    return call_az("az policy exemption list", locals())


def show(name, resource_group=None, scope=None):
    '''
    Show a policy exemption.
    '''
    return call_az("az policy exemption show", locals())


def update(name, description=None, display_name=None, exemption_category=None, expires_on=None, metadata=None, policy_definition_reference_ids=None, resource_group=None, scope=None):
    '''
    Update a policy exemption.
    '''
    return call_az("az policy exemption update", locals())




from .... pyaz_utils import call_az

def list(name, resource_group):
    return call_az("az batch account keys list", locals())


def renew(key_name=None, name=None, resource_group=None):
    '''
    Renew keys for a Batch account.
    '''
    return call_az("az batch account keys renew", locals())




from .... pyaz_utils import call_az

def show(name, resource_group):
    return call_az("az eventgrid partner registration show", locals())


def delete(name, resource_group, yes=None):
    return call_az("az eventgrid partner registration delete", locals())


def list(odata_query=None, resource_group=None):
    '''
    List all partner registrations in specific resource group or all under the specified azure subscription.
    '''
    return call_az("az eventgrid partner registration list", locals())


def create(name, partner_name, resource_group, resource_type_name, authorized_subscription_ids=None, customer_service_extension=None, customer_service_number=None, customer_service_uri=None, description=None, display_name=None, logo_uri=None, long_description=None, setup_uri=None, tags=None):
    '''
    Create a new partner registration.
    '''
    return call_az("az eventgrid partner registration create", locals())




from .... pyaz_utils import call_az

def list(kusto_pool_name, resource_group, workspace_name):
    '''
    Returns the list of attached database configurations of the given Kusto Pool.
    '''
    return call_az("az synapse kusto attached-database-configuration list", locals())


def show(attached_database_configuration_name, kusto_pool_name, resource_group, workspace_name):
    '''
    Returns an attached database configuration.
    '''
    return call_az("az synapse kusto attached-database-configuration show", locals())


def create(attached_database_configuration_name, kusto_pool_name, resource_group, workspace_name, database_name=None, default_principals_modification_kind=None, kusto_pool_resource_id=None, location=None, no_wait=None, table_level_sharing_properties=None):
    '''
    Create an attached database configuration.
    '''
    return call_az("az synapse kusto attached-database-configuration create", locals())


def update(attached_database_configuration_name, kusto_pool_name, resource_group, workspace_name, add=None, database_name=None, default_principals_modification_kind=None, force_string=None, kusto_pool_resource_id=None, location=None, no_wait=None, remove=None, set=None, table_level_sharing_properties=None):
    '''
    Update an attached database configuration.
    '''
    return call_az("az synapse kusto attached-database-configuration update", locals())


def delete(attached_database_configuration_name, kusto_pool_name, resource_group, workspace_name, no_wait=None, yes=None):
    '''
    Deletes the attached database configuration with the given name.
    '''
    return call_az("az synapse kusto attached-database-configuration delete", locals())


def wait(attached_database_configuration_name, kusto_pool_name, resource_group, workspace_name, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the synapse kusto attached-database-configuration is met.
    '''
    return call_az("az synapse kusto attached-database-configuration wait", locals())




from ... pyaz_utils import call_az

def list(location=None, resource_group=None):
    '''
    List your Just in Time network access policies.
    '''
    return call_az("az security jit-policy list", locals())


def show(location, name, resource_group):
    '''
    Shows a Just in Time network access policy.
    '''
    return call_az("az security jit-policy show", locals())




from .... pyaz_utils import call_az

def create(message, name, policy_definition_reference_id=None, resource_group=None, scope=None):
    '''
    Add a non-compliance message to a policy assignment.
    '''
    return call_az("az policy assignment non-compliance-message create", locals())


def list(name, resource_group=None, scope=None):
    '''
    List the non-compliance messages for a policy assignment.
    '''
    return call_az("az policy assignment non-compliance-message list", locals())


def delete(message, name, policy_definition_reference_id=None, resource_group=None, scope=None):
    '''
    Remove one or more non-compliance messages from a policy assignment.
    '''
    return call_az("az policy assignment non-compliance-message delete", locals())




from ... pyaz_utils import call_az

def list(location):
    '''
    Show all commitment tiers for Azure Cognitive Services.
    '''
    return call_az("az cognitiveservices commitment-tier list", locals())




from .... pyaz_utils import call_az

def list(grain, reservation_order_id, end_date=None, reservation_id=None, start_date=None):
    '''
    List reservation summaries for daily or monthly by order Id or reservation id.
    '''
    return call_az("az consumption reservation summary list", locals())




from .... pyaz_utils import call_az

def postgres(client_type=None, connection=None, database=None, name=None, new=None, no_wait=None, resource_group=None, secret=None, server=None, source_id=None, target_id=None, target_resource_group=None):
    '''
    Create a webapp connection to postgres.
    '''
    return call_az("az webapp connection create postgres", locals())


def postgres_flexible(client_type=None, connection=None, database=None, name=None, no_wait=None, resource_group=None, secret=None, server=None, source_id=None, target_id=None, target_resource_group=None):
    '''
    Create a webapp connection to postgres-flexible.
    '''
    return call_az("az webapp connection create postgres-flexible", locals())


def mysql(client_type=None, connection=None, database=None, name=None, no_wait=None, resource_group=None, secret=None, server=None, source_id=None, target_id=None, target_resource_group=None):
    '''
    Create a webapp connection to mysql.
    '''
    return call_az("az webapp connection create mysql", locals())


def mysql_flexible(client_type=None, connection=None, database=None, name=None, no_wait=None, resource_group=None, secret=None, server=None, source_id=None, target_id=None, target_resource_group=None):
    '''
    Create a webapp connection to mysql-flexible.
    '''
    return call_az("az webapp connection create mysql-flexible", locals())


def cosmos_cassandra(account=None, client_type=None, connection=None, key_space=None, name=None, no_wait=None, resource_group=None, secret=None, service_principal=None, source_id=None, system_identity=None, target_id=None, target_resource_group=None, user_identity=None):
    '''
    Create a webapp connection to cosmos-cassandra.
    '''
    return call_az("az webapp connection create cosmos-cassandra", locals())


def cosmos_gremlin(account=None, client_type=None, connection=None, database=None, graph=None, name=None, no_wait=None, resource_group=None, secret=None, service_principal=None, source_id=None, system_identity=None, target_id=None, target_resource_group=None, user_identity=None):
    '''
    Create a webapp connection to cosmos-gremlin.
    '''
    return call_az("az webapp connection create cosmos-gremlin", locals())


def cosmos_mongo(account=None, client_type=None, connection=None, database=None, name=None, no_wait=None, resource_group=None, secret=None, service_principal=None, source_id=None, system_identity=None, target_id=None, target_resource_group=None, user_identity=None):
    '''
    Create a webapp connection to cosmos-mongo.
    '''
    return call_az("az webapp connection create cosmos-mongo", locals())


def cosmos_table(account=None, client_type=None, connection=None, name=None, no_wait=None, resource_group=None, secret=None, service_principal=None, source_id=None, system_identity=None, table=None, target_id=None, target_resource_group=None, user_identity=None):
    '''
    Create a webapp connection to cosmos-table.
    '''
    return call_az("az webapp connection create cosmos-table", locals())


def cosmos_sql(account=None, client_type=None, connection=None, database=None, name=None, no_wait=None, resource_group=None, secret=None, service_principal=None, source_id=None, system_identity=None, target_id=None, target_resource_group=None, user_identity=None):
    '''
    Create a webapp connection to cosmos-sql.
    '''
    return call_az("az webapp connection create cosmos-sql", locals())


def storage_blob(account=None, client_type=None, connection=None, name=None, new=None, no_wait=None, resource_group=None, secret=None, service_principal=None, source_id=None, system_identity=None, target_id=None, target_resource_group=None, user_identity=None):
    '''
    Create a webapp connection to storage-blob.
    '''
    return call_az("az webapp connection create storage-blob", locals())


def storage_queue(account=None, client_type=None, connection=None, name=None, no_wait=None, resource_group=None, secret=None, service_principal=None, source_id=None, system_identity=None, target_id=None, target_resource_group=None, user_identity=None):
    '''
    Create a webapp connection to storage-queue.
    '''
    return call_az("az webapp connection create storage-queue", locals())


def storage_file(account=None, client_type=None, connection=None, name=None, no_wait=None, resource_group=None, secret=None, source_id=None, target_id=None, target_resource_group=None):
    '''
    Create a webapp connection to storage-file.
    '''
    return call_az("az webapp connection create storage-file", locals())


def storage_table(account=None, client_type=None, connection=None, name=None, no_wait=None, resource_group=None, secret=None, source_id=None, target_id=None, target_resource_group=None):
    '''
    Create a webapp connection to storage-table.
    '''
    return call_az("az webapp connection create storage-table", locals())


def keyvault(client_type=None, connection=None, name=None, new=None, no_wait=None, resource_group=None, service_principal=None, source_id=None, system_identity=None, target_id=None, target_resource_group=None, user_identity=None, vault=None):
    '''
    Create a webapp connection to keyvault.
    '''
    return call_az("az webapp connection create keyvault", locals())


def signalr(client_type=None, connection=None, name=None, no_wait=None, resource_group=None, secret=None, service_principal=None, signalr=None, source_id=None, system_identity=None, target_id=None, target_resource_group=None, user_identity=None):
    '''
    Create a webapp connection to signalr.
    '''
    return call_az("az webapp connection create signalr", locals())


def confluent_cloud(bootstrap_server, kafka_key, kafka_secret, schema_key, schema_registry, schema_secret, client_type=None, connection=None, name=None, no_wait=None, resource_group=None, source_id=None):
    '''
    Create a webapp connection to confluent-cloud.
    '''
    return call_az("az webapp connection create confluent-cloud", locals())




from ... pyaz_utils import call_az

def start(name, post_migration_name, resource_group, target_namespace):
    '''
    Create and Start Service Bus Migration of Standard to Premium namespace.
    '''
    return call_az("az servicebus migration start", locals())


def show(name, resource_group):
    '''
    shows properties of properties of Service Bus Migration
    '''
    return call_az("az servicebus migration show", locals())


def complete(name, resource_group):
    '''
    Completes the Service Bus Migration of Standard to Premium namespace
    '''
    return call_az("az servicebus migration complete", locals())


def abort(name, resource_group):
    '''
    Disable the Service Bus Migration of Standard to Premium namespace
    '''
    return call_az("az servicebus migration abort", locals())




from ... pyaz_utils import call_az
from . import rotation_policy


def list(hsm_name=None, id=None, include_managed=None, maxresults=None, vault_name=None):
    '''
    List keys in the specified Vault or HSM.
    '''
    return call_az("az keyvault key list", locals())


def list_versions(hsm_name=None, id=None, maxresults=None, name=None, vault_name=None):
    return call_az("az keyvault key list-versions", locals())


def list_deleted(hsm_name=None, id=None, maxresults=None, vault_name=None):
    '''
    List the deleted keys in the specified Vault or HSM.
    '''
    return call_az("az keyvault key list-deleted", locals())


def show_deleted(hsm_name=None, id=None, name=None, vault_name=None):
    '''
    Get the public part of a deleted key.
    '''
    return call_az("az keyvault key show-deleted", locals())


def delete(hsm_name=None, id=None, name=None, vault_name=None):
    '''
    Delete a key of any type from storage in Vault or HSM.
    '''
    return call_az("az keyvault key delete", locals())


def purge(hsm_name=None, id=None, name=None, vault_name=None):
    '''
    Permanently delete the specified key.
    '''
    return call_az("az keyvault key purge", locals())


def recover(hsm_name=None, id=None, name=None, vault_name=None):
    '''
    Recover the deleted key to its latest version.
    '''
    return call_az("az keyvault key recover", locals())


def backup(file, hsm_name=None, id=None, name=None, vault_name=None):
    '''
    Request that a backup of the specified key be downloaded to the client.
    '''
    return call_az("az keyvault key backup", locals())


def restore(backup_folder=None, blob_container_name=None, file=None, hsm_name=None, id=None, name=None, no_wait=None, storage_account_name=None, storage_container_SAS_token=None, storage_resource_uri=None, vault_name=None):
    '''
    Restore a backed up key to a Vault or HSM.
    '''
    return call_az("az keyvault key restore", locals())


def download(file, encoding=None, hsm_name=None, id=None, name=None, vault_name=None, version=None):
    '''
    Download the public part of a stored key.
    '''
    return call_az("az keyvault key download", locals())


def create(curve=None, disabled=None, expires=None, exportable=None, hsm_name=None, id=None, kty=None, name=None, not_before=None, ops=None, policy=None, protection=None, size=None, tags=None, vault_name=None):
    '''
    Create a new key, stores it, then returns key parameters and attributes to the client.
    '''
    return call_az("az keyvault key create", locals())


def set_attributes(enabled=None, expires=None, hsm_name=None, id=None, name=None, not_before=None, ops=None, policy=None, tags=None, vault_name=None, version=None):
    '''
    The update key operation changes specified attributes of a stored key and can be applied to any key type and key version stored in Vault or HSM.
    '''
    return call_az("az keyvault key set-attributes", locals())


def show(hsm_name=None, id=None, name=None, vault_name=None, version=None):
    return call_az("az keyvault key show", locals())


def import_(byok_file=None, byok_string=None, curve=None, disabled=None, expires=None, exportable=None, hsm_name=None, id=None, kty=None, name=None, not_before=None, ops=None, pem_file=None, pem_password=None, pem_string=None, policy=None, protection=None, tags=None, vault_name=None):
    return call_az("az keyvault key import", locals())


def get_policy_template():
    '''
    Return policy template as JSON encoded policy definition.
    '''
    return call_az("az keyvault key get-policy-template", locals())


def encrypt(algorithm, value, aad=None, data_type=None, hsm_name=None, id=None, iv=None, name=None, vault_name=None, version=None):
    '''
    Encrypt an arbitrary sequence of bytes using an encryption key that is stored in a Vault or HSM.
    '''
    return call_az("az keyvault key encrypt", locals())


def decrypt(algorithm, value, aad=None, data_type=None, hsm_name=None, id=None, iv=None, name=None, tag=None, vault_name=None, version=None):
    '''
    Decrypt a single block of encrypted data.
    '''
    return call_az("az keyvault key decrypt", locals())


def random(count, hsm_name=None, id=None):
    return call_az("az keyvault key random", locals())


def rotate(hsm_name=None, id=None, name=None, vault_name=None):
    '''
    Rotate the key based on the key policy by generating a new version of the key.
    '''
    return call_az("az keyvault key rotate", locals())




from .... pyaz_utils import call_az

def configure(nsg, enabled=None, format=None, interval=None, log_version=None, resource_group=None, retention=None, storage_account=None, traffic_analytics=None, workspace=None):
    '''
    Configure flow logging on a network security group.
    '''
    return call_az("az network watcher flow-log configure", locals())


def show(location=None, name=None, nsg=None, resource_group=None):
    '''
    Get the flow log configuration of a network security group.
    '''
    return call_az("az network watcher flow-log show", locals())


def list(location):
    '''
    List all flow log resources for the specified Network Watcher
    '''
    return call_az("az network watcher flow-log list", locals())


def delete(location, name):
    '''
    Delete the specified flow log resource.
    '''
    return call_az("az network watcher flow-log delete", locals())


def create(location, name, nsg, enabled=None, format=None, interval=None, log_version=None, resource_group=None, retention=None, storage_account=None, tags=None, traffic_analytics=None, workspace=None):
    '''
    Create a flow log on a network security group.
    '''
    return call_az("az network watcher flow-log create", locals())


def update(location, name, add=None, enabled=None, force_string=None, format=None, interval=None, log_version=None, nsg=None, remove=None, resource_group=None, retention=None, set=None, storage_account=None, tags=None, traffic_analytics=None, workspace=None):
    '''
    Update the flow log configuration of a network security group
    '''
    return call_az("az network watcher flow-log update", locals())




from ... pyaz_utils import call_az
from . import backup, export_policy, replication


def show(account_name, pool_name, resource_group, volume_name):
    '''
    Get the specified ANF volume.
    '''
    return call_az("az netappfiles volume show", locals())


def list(account_name, pool_name, resource_group):
    '''
    List the ANF Pools for the specified account.
    '''
    return call_az("az netappfiles volume list", locals())


def delete(account_name, pool_name, resource_group, volume_name):
    '''
    Delete the specified ANF volume.
    '''
    return call_az("az netappfiles volume delete", locals())


def create(account_name, file_path, location, pool_name, resource_group, usage_threshold, vnet, volume_name, allowed_clients=None, avs_data_store=None, backup_enabled=None, backup_id=None, backup_policy_id=None, chown_mode=None, cifs=None, cool_access=None, coolness_period=None, default_group_quota=None, default_user_quota=None, encryption_key_source=None, endpoint_type=None, has_root_access=None, is_def_quota_enabled=None, kerberos5_r=None, kerberos5_rw=None, kerberos5i_r=None, kerberos5i_rw=None, kerberos5p_r=None, kerberos5p_rw=None, kerberos_enabled=None, ldap_enabled=None, network_features=None, policy_enforced=None, protocol_types=None, remote_volume_resource_id=None, replication_schedule=None, rule_index=None, security_style=None, service_level=None, smb_continuously_avl=None, smb_encryption=None, snapshot_dir_visible=None, snapshot_id=None, snapshot_policy_id=None, subnet=None, tags=None, throughput_mibps=None, unix_permissions=None, unix_read_only=None, unix_read_write=None, vault_id=None, volume_type=None):
    '''
    Create a new Azure NetApp Files (ANF) volume. Export policies are applied with the subgroup commands but note that volumes are always created with a default export policy
    '''
    return call_az("az netappfiles volume create", locals())


def update(account_name, pool_name, resource_group, volume_name, add=None, backup_enabled=None, backup_policy_id=None, default_group_quota=None, default_user_quota=None, force_string=None, is_def_quota_enabled=None, policy_enforced=None, remove=None, service_level=None, set=None, snapshot_policy_id=None, tags=None, throughput_mibps=None, usage_threshold=None, vault_id=None):
    '''
    Update the specified ANF volume with the values provided. Unspecified values will remain unchanged. Export policies are amended/created with the subgroup commands
    '''
    return call_az("az netappfiles volume update", locals())


def revert(account_name, pool_name, resource_group, snapshot_id, volume_name):
    '''
    Revert a volume to one of its snapshots.
    '''
    return call_az("az netappfiles volume revert", locals())


def pool_change(account_name, new_pool_resource_id, pool_name, resource_group, volume_name):
    '''
    Change pool for an Azure NetApp Files (ANF) volume.
    '''
    return call_az("az netappfiles volume pool-change", locals())




from ... pyaz_utils import call_az

def create(account_name, asset_name, name, resource_group, streaming_policy_name, alternative_media_id=None, content_key_policy_name=None, content_keys=None, end_time=None, filters=None, start_time=None, streaming_locator_id=None):
    '''
    Create a streaming locator.
    '''
    return call_az("az ams streaming-locator create", locals())


def list(account_name, resource_group, filter=None, orderby=None, top=None):
    '''
    List all the streaming locators within an Azure Media Services account.
    '''
    return call_az("az ams streaming-locator list", locals())


def show(account_name, name, resource_group):
    '''
    Show the details of a streaming locator.
    '''
    return call_az("az ams streaming-locator show", locals())


def delete(account_name, name, resource_group):
    return call_az("az ams streaming-locator delete", locals())


def get_paths(account_name, name, resource_group):
    '''
    List paths supported by a streaming locator.
    '''
    return call_az("az ams streaming-locator get-paths", locals())


def list_content_keys(account_name, name, resource_group):
    '''
    List content keys used by a streaming locator.
    '''
    return call_az("az ams streaming-locator list-content-keys", locals())




from ... pyaz_utils import call_az

def cancel(name, resource_group):
    return call_az("az vmss rolling-upgrade cancel", locals())


def get_latest(name, resource_group):
    return call_az("az vmss rolling-upgrade get-latest", locals())


def start(name, resource_group):
    return call_az("az vmss rolling-upgrade start", locals())




from ... pyaz_utils import call_az

def create(deployment_mode, parameters_path, resource_group, service_name, service_topology_name, service_unit_name, target_resource_group, template_path, location=None, tags=None):
    '''
    Creates a service unit under the specified service and service topology.
    '''
    return call_az("az deploymentmanager service-unit create", locals())


def delete(resource_group, service_name, service_topology_name, service_unit_name):
    '''
    Deletes the service unit.
    '''
    return call_az("az deploymentmanager service-unit delete", locals())


def show(resource_group, service_name, service_topology_name, service_unit_name):
    '''
    Get the details of a service unit.
    '''
    return call_az("az deploymentmanager service-unit show", locals())


def list(resource_group, service_name, service_topology_name):
    '''
    List all service units in a service.
    '''
    return call_az("az deploymentmanager service-unit list", locals())


def update(resource_group, service_name, service_topology_name, service_unit_name, add=None, deployment_mode=None, force_string=None, parameters_path=None, remove=None, set=None, tags=None, target_resource_group=None, template_path=None):
    '''
    Updates the service unit.
    '''
    return call_az("az deploymentmanager service-unit update", locals())




from ... pyaz_utils import call_az

def show(custom_domain_name, profile_name, resource_group):
    '''
    Show the custom domain details.
    '''
    return call_az("az afd custom-domain show", locals())


def wait(custom_domain_name, profile_name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the custom domain is met.
    '''
    return call_az("az afd custom-domain wait", locals())


def delete(custom_domain_name, profile_name, resource_group, yes=None):
    '''
    Delete a custom domain.
    '''
    return call_az("az afd custom-domain delete", locals())


def list(profile_name, resource_group):
    '''
    List all the custom domains within the specified profile.
    '''
    return call_az("az afd custom-domain list", locals())


def create(certificate_type, custom_domain_name, host_name, minimum_tls_version, profile_name, resource_group, azure_dns_zone=None, no_wait=None, secret=None):
    '''
    Create a custom domain within the specified profile.
    '''
    return call_az("az afd custom-domain create", locals())


def update(custom_domain_name, profile_name, resource_group, azure_dns_zone=None, certificate_type=None, minimum_tls_version=None, secret=None):
    '''
    Update a custom domain within the specified profile.
    '''
    return call_az("az afd custom-domain update", locals())




from ... pyaz_utils import call_az

def list(name, resource_group=None):
    '''
    List custom hostnames of the static app.
    '''
    return call_az("az staticwebapp hostname list", locals())


def set(hostname, name, no_wait=None, resource_group=None, validation_method=None):
    '''
    Set given sub-domain hostname to the static app. Please configure CNAME/TXT/ALIAS record with your DNS provider. Use --no-wait to not wait for validation.
    '''
    return call_az("az staticwebapp hostname set", locals())


def delete(hostname, name, no_wait=None, resource_group=None, yes=None):
    '''
    Delete given hostname of the static app.
    '''
    return call_az("az staticwebapp hostname delete", locals())


def show(hostname, name, resource_group):
    '''
    Get details for a staticwebapp custom domain. Can be used to fetch validation token for TXT domain validation (see example).
    '''
    return call_az("az staticwebapp hostname show", locals())




from ... pyaz_utils import call_az
from . import authorization_rule


def create(name, namespace_name, resource_group, auto_delete_on_idle=None, default_message_time_to_live=None, duplicate_detection_history_time_window=None, enable_batched_operations=None, enable_dead_lettering_on_message_expiration=None, enable_duplicate_detection=None, enable_express=None, enable_partitioning=None, enable_session=None, forward_dead_lettered_messages_to=None, forward_to=None, lock_duration=None, max_delivery_count=None, max_size=None, status=None):
    '''
    Create the Service Bus Queue
    '''
    return call_az("az servicebus queue create", locals())


def show(name, namespace_name, resource_group):
    '''
    shows the Service Bus Queue Details
    '''
    return call_az("az servicebus queue show", locals())


def list(namespace_name, resource_group, skip=None, top=None):
    '''
    List the Queue by Service Bus Namespace
    '''
    return call_az("az servicebus queue list", locals())


def delete(name, namespace_name, resource_group):
    '''
    Deletes the Service Bus Queue
    '''
    return call_az("az servicebus queue delete", locals())


def update(name, namespace_name, resource_group, add=None, auto_delete_on_idle=None, default_message_time_to_live=None, duplicate_detection_history_time_window=None, enable_batched_operations=None, enable_dead_lettering_on_message_expiration=None, enable_duplicate_detection=None, enable_express=None, enable_partitioning=None, enable_session=None, force_string=None, forward_dead_lettered_messages_to=None, forward_to=None, lock_duration=None, max_delivery_count=None, max_size=None, remove=None, set=None, status=None):
    '''
    Updates existing Service Bus Queue
    '''
    return call_az("az servicebus queue update", locals())




from ... pyaz_utils import call_az
from . import section


def list(period_end_date, period_start_date, account_name=None, profile_name=None):
    '''
    List the invoices for a subscription.
    '''
    return call_az("az billing invoice list", locals())


def show(name, account_name=None, by_subscription=None):
    '''
    Get an invoice. The operation is supported for billing accounts with agreement type Microsoft Partner Agreement or Microsoft Customer Agreement.
    '''
    return call_az("az billing invoice show", locals())


def download(account_name=None, download_token=None, download_urls=None, invoice_name=None):
    '''
    Get URL to download invoice
    '''
    return call_az("az billing invoice download", locals())




from ... pyaz_utils import call_az

def list(device_name, resource_group):
    '''
    Get all the alerts for a Data Box Edge/Data Box Gateway device.
    '''
    return call_az("az databoxedge alert list", locals())


def show(device_name, name, resource_group):
    '''
    Get an alert by name.
    '''
    return call_az("az databoxedge alert show", locals())




from ... pyaz_utils import call_az
from . import authorization_rule, network_rule


def create(name, resource_group, capacity=None, default_action=None, location=None, sku=None, tags=None):
    '''
    Create a Service Bus Namespace
    '''
    return call_az("az servicebus namespace create", locals())


def show(name, resource_group):
    '''
    Shows the Service Bus Namespace details
    '''
    return call_az("az servicebus namespace show", locals())


def list(resource_group=None):
    '''
    List the Service Bus Namespaces
    '''
    return call_az("az servicebus namespace list", locals())


def delete(name, resource_group):
    '''
    Deletes the Service Bus Namespace
    '''
    return call_az("az servicebus namespace delete", locals())


def exists(name):
    '''
    check for the availability of the given name for the Namespace
    '''
    return call_az("az servicebus namespace exists", locals())


def update(name, resource_group, add=None, capacity=None, default_action=None, force_string=None, remove=None, set=None, sku=None, tags=None):
    '''
    Updates a Service Bus Namespace
    '''
    return call_az("az servicebus namespace update", locals())




from ... pyaz_utils import call_az

def create(name, resource_group, add_disabled=None, calling_web_hook=None, enable_calling=None, enable_groups=None, enable_media_cards=None, enable_messaging=None, enable_screen_sharing=None, enable_video=None, groups_mode=None):
    '''
    Create the Skype Channel on a bot.
    '''
    return call_az("az bot skype create", locals())


def show(name, resource_group, with_secrets=None):
    '''
    Get details of the Skype Channel on a bot
    '''
    return call_az("az bot skype show", locals())


def delete(name, resource_group):
    '''
    Delete the Skype Channel on a bot
    '''
    return call_az("az bot skype delete", locals())




from ... pyaz_utils import call_az

def create(name, resource_group, location=None, tags=None):
    '''
    Create an application security group.
    '''
    return call_az("az network asg create", locals())


def show(name, resource_group):
    '''
    Get details of an application security group.
    '''
    return call_az("az network asg show", locals())


def list():
    '''
    List all application security groups in a subscription.
    '''
    return call_az("az network asg list", locals())


def delete(name, resource_group):
    '''
    Delete an application security group.
    '''
    return call_az("az network asg delete", locals())


def update(name, resource_group, add=None, force_string=None, remove=None, set=None, tags=None):
    '''
    Update an application security group.
    '''
    return call_az("az network asg update", locals())




from .... pyaz_utils import call_az

def show(account, pipeline_identity, end_date_time=None, start_date_time=None):
    '''
    Retrieve a job pipeline in a Data Lake Analytics account.
    '''
    return call_az("az dla job pipeline show", locals())


def list(account, end_date_time=None, start_date_time=None):
    '''
    List job pipelines in a Data Lake Analytics account.
    '''
    return call_az("az dla job pipeline list", locals())




from .... pyaz_utils import call_az
from . import audit_policy, classification, tde, threat_policy


def show(name, resource_group, workspace_name):
    '''
    Get a SQL pool.
    '''
    return call_az("az synapse sql pool show", locals())


def list(resource_group, workspace_name):
    '''
    List all SQL pools.
    '''
    return call_az("az synapse sql pool list", locals())


def create(name, performance_level, resource_group, workspace_name, no_wait=None, tags=None):
    '''
    Create a SQL pool.
    '''
    return call_az("az synapse sql pool create", locals())


def delete(name, resource_group, workspace_name, no_wait=None, yes=None):
    '''
    Delete a SQL pool.
    '''
    return call_az("az synapse sql pool delete", locals())


def update(name, resource_group, workspace_name, performance_level=None, tags=None):
    '''
    Update a SQL pool.
    '''
    return call_az("az synapse sql pool update", locals())


def pause(name, resource_group, workspace_name):
    '''
    Pause a SQL pool.
    '''
    return call_az("az synapse sql pool pause", locals())


def resume(name, resource_group, workspace_name):
    '''
    Resume a SQL pool.
    '''
    return call_az("az synapse sql pool resume", locals())


def restore(dest_name, name, resource_group, workspace_name, deleted_time=None, performance_level=None, time=None):
    '''
    Create a new SQL pool by restoring from a backup.
    '''
    return call_az("az synapse sql pool restore", locals())


def show_connection_string(client, auth_type=None, name=None, workspace_name=None):
    '''
    Generate a connection string to a SQL pool.
    '''
    return call_az("az synapse sql pool show-connection-string", locals())


def wait(resource_group, sql_pool_name, workspace_name, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of a SQL pool is met.
    '''
    return call_az("az synapse sql pool wait", locals())


def list_deleted(resource_group, workspace_name):
    '''
    List all deleted SQL pools.
    '''
    return call_az("az synapse sql pool list-deleted", locals())




from ... pyaz_utils import call_az

def list(cluster_name, resource_group):
    '''
    List node pools in the managed Kubernetes cluster.
    '''
    return call_az("az aks nodepool list", locals())


def show(cluster_name, name, resource_group):
    '''
    Show the details for a node pool in the managed Kubernetes cluster.
    '''
    return call_az("az aks nodepool show", locals())


def add(cluster_name, name, resource_group, enable_cluster_autoscaler=None, enable_encryption_at_host=None, enable_node_public_ip=None, enable_ultra_ssd=None, eviction_policy=None, kubernetes_version=None, labels=None, max_count=None, max_pods=None, max_surge=None, min_count=None, mode=None, no_wait=None, node_count=None, node_osdisk_size=None, node_osdisk_type=None, node_public_ip_prefix_id=None, node_taints=None, node_vm_size=None, os_sku=None, os_type=None, ppg=None, priority=None, spot_max_price=None, tags=None, vnet_subnet_id=None, zones=None):
    '''
    Add a node pool to the managed Kubernetes cluster.
    '''
    return call_az("az aks nodepool add", locals())


def scale(cluster_name, name, resource_group, no_wait=None, node_count=None):
    '''
    Scale the node pool in a managed Kubernetes cluster.
    '''
    return call_az("az aks nodepool scale", locals())


def upgrade(cluster_name, name, resource_group, kubernetes_version=None, max_surge=None, no_wait=None, node_image_only=None):
    '''
    Upgrade the node pool in a managed Kubernetes cluster.
    '''
    return call_az("az aks nodepool upgrade", locals())


def update(cluster_name, name, resource_group, disable_cluster_autoscaler=None, enable_cluster_autoscaler=None, labels=None, max_count=None, max_surge=None, min_count=None, mode=None, no_wait=None, tags=None, update_cluster_autoscaler=None):
    '''
    Update a node pool to enable/disable cluster-autoscaler or change min-count or max-count
    '''
    return call_az("az aks nodepool update", locals())


def delete(cluster_name, name, resource_group, no_wait=None):
    '''
    Delete the agent pool in the managed Kubernetes cluster.
    '''
    return call_az("az aks nodepool delete", locals())


def get_upgrades(cluster_name, nodepool_name, resource_group):
    '''
    Get the available upgrade versions for an agent pool of the managed Kubernetes cluster.
    '''
    return call_az("az aks nodepool get-upgrades", locals())




from .... pyaz_utils import call_az

def list(management_group_id, name):
    '''
    List deployment operations at management group.
    '''
    return call_az("az deployment operation mg list", locals())


def show(management_group_id, name, operation_ids):
    '''
    Show a deployment operation at management group.
    '''
    return call_az("az deployment operation mg show", locals())




from .. pyaz_utils import call_az

def list(resource_id=None):
    '''
    List the entire set of tags on a specific resource.
    '''
    return call_az("az tag list", locals())


def create(name=None, resource_id=None, tags=None):
    '''
    Create tags on a specific resource.
    '''
    return call_az("az tag create", locals())


def delete(name=None, resource_id=None, yes=None):
    '''
    Delete tags on a specific resource.
    '''
    return call_az("az tag delete", locals())


def update(operation, resource_id, tags):
    '''
    Selectively update the set of tags on a specific resource.
    '''
    return call_az("az tag update", locals())


def add_value(name, value):
    '''
    Create a tag value.
    '''
    return call_az("az tag add-value", locals())


def remove_value(name, value):
    return call_az("az tag remove-value", locals())




from .. pyaz_utils import call_az

def create(name, resource_group, location=None, tags=None):
    return call_az("az identity create", locals())


def show(name, resource_group):
    return call_az("az identity show", locals())


def delete(name, resource_group):
    return call_az("az identity delete", locals())


def list(resource_group=None):
    '''
    List Managed Service Identities
    '''
    return call_az("az identity list", locals())


def list_operations():
    '''
    Lists available operations for the Managed Identity provider
    '''
    return call_az("az identity list-operations", locals())




from .... pyaz_utils import call_az

def show(managed_instance, resource_group):
    return call_az("az sql mi tde-key show", locals())


def set(managed_instance, resource_group, server_key_type, auto_rotation_enabled=None, kid=None):
    '''
    Sets the SQL Instance's encryption protector.
    '''
    return call_az("az sql mi tde-key set", locals())




from .... pyaz_utils import call_az
from . import rule


def show(account_name, policy_id, resource_group=None):
    '''
    Show the properties of specified Object Replication Service Policy for storage account.
    '''
    return call_az("az storage account or-policy show", locals())


def list(account_name, resource_group=None):
    '''
    List Object Replication Service Policies associated with the specified storage account.
    '''
    return call_az("az storage account or-policy list", locals())


def create(account_name, destination_account=None, destination_container=None, min_creation_time=None, policy=None, policy_id=None, prefix_match=None, resource_group=None, rule_id=None, source_account=None, source_container=None):
    '''
    Create Object Replication Service Policy for storage account.
    '''
    return call_az("az storage account or-policy create", locals())


def update(account_name, add=None, destination_account=None, force_string=None, policy=None, policy_id=None, remove=None, resource_group=None, set=None, source_account=None):
    '''
    Update Object Replication Service Policy properties for storage account.
    '''
    return call_az("az storage account or-policy update", locals())


def delete(account_name, policy_id, resource_group=None):
    '''
    Delete specified Object Replication Service Policy associated with the specified storage account.
    '''
    return call_az("az storage account or-policy delete", locals())




from .. pyaz_utils import call_az
from . import application, autoscale, azure_monitor, host, monitor, script_action


def create(name, resource_group, type, assign_identity=None, autoscale_max_workernode_count=None, autoscale_min_workernode_count=None, autoscale_type=None, autoscale_workernode_count=None, cluster_admin_account=None, cluster_admin_password=None, cluster_configurations=None, cluster_tier=None, cluster_users_group_dns=None, component_version=None, days=None, domain=None, edgenode_size=None, enable_compute_isolation=None, enable_private_link=None, encryption_algorithm=None, encryption_at_host=None, encryption_in_transit=None, encryption_key_name=None, encryption_key_version=None, encryption_vault_uri=None, esp=None, headnode_size=None, host_sku=None, http_password=None, http_user=None, idbroker=None, kafka_client_group_id=None, kafka_client_group_name=None, kafka_management_node_count=None, kafka_management_node_size=None, ldaps_urls=None, location=None, minimal_tls_version=None, no_validation_timeout=None, no_wait=None, private_link_config=None, resource_provider_connection=None, ssh_password=None, ssh_public_key=None, ssh_user=None, storage_account=None, storage_account_key=None, storage_account_managed_identity=None, storage_container=None, storage_filesystem=None, subnet=None, tags=None, time=None, timezone=None, version=None, vnet_name=None, workernode_count=None, workernode_data_disk_size=None, workernode_data_disk_storage_account_type=None, workernode_data_disks_per_node=None, workernode_size=None, zones=None, zookeepernode_size=None):
    '''
    Create a new cluster.
    '''
    return call_az("az hdinsight create", locals())


def resize(name, resource_group, workernode_count, no_wait=None):
    '''
    Resize the specified HDInsight cluster to the specified size.
    '''
    return call_az("az hdinsight resize", locals())


def show(name, resource_group):
    return call_az("az hdinsight show", locals())


def list(resource_group=None):
    '''
    List HDInsight clusters in a resource group or subscription.
    '''
    return call_az("az hdinsight list", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until an operation is complete.
    '''
    return call_az("az hdinsight wait", locals())


def delete(name, resource_group, no_wait=None, yes=None):
    return call_az("az hdinsight delete", locals())


def rotate_disk_encryption_key(encryption_key_name, encryption_key_version, encryption_vault_uri, name, resource_group, no_wait=None):
    '''
    Rotate the disk encryption key of the specified HDInsight cluster.
    '''
    return call_az("az hdinsight rotate-disk-encryption-key", locals())


def update(name, resource_group, no_wait=None, tags=None):
    '''
    Update the tags of the specified HDInsight cluster.
    '''
    return call_az("az hdinsight update", locals())


def list_usage(location):
    return call_az("az hdinsight list-usage", locals())




from ... pyaz_utils import call_az
from . import image


def delete(name, resource_group, vm_name, no_wait=None):
    '''
    Remove an extension attached to a VM.
    '''
    return call_az("az vm extension delete", locals())


def show(name, resource_group, vm_name, expand=None):
    '''
    Display information about extensions attached to a VM.
    '''
    return call_az("az vm extension show", locals())


def set(name, publisher, resource_group, vm_name, enable_auto_upgrade=None, extension_instance_name=None, force_update=None, no_auto_upgrade_minor_version=None, no_wait=None, protected_settings=None, settings=None, version=None):
    '''
    Set extensions for a VM.
    '''
    return call_az("az vm extension set", locals())


def list(resource_group, vm_name):
    '''
    List the extensions attached to a VM.
    '''
    return call_az("az vm extension list", locals())


def wait(name, resource_group, vm_name, created=None, custom=None, deleted=None, exists=None, expand=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of a virtual machine extension is met.
    '''
    return call_az("az vm extension wait", locals())




from .... pyaz_utils import call_az

def list(custom_domains, date_time_begin, date_time_end, granularity, metrics, profile_name, protocols, resource_group, continents=None, country_or_regions=None, group_by=None):
    return call_az("az afd log-analytic metric list", locals())




from ... pyaz_utils import call_az

def approve(account_name=None, description=None, id=None, name=None, resource_group=None):
    '''
    Approve the specified private endpoint connection associated with Azure Cosmos DB.
    '''
    return call_az("az cosmosdb private-endpoint-connection approve", locals())


def reject(account_name=None, description=None, id=None, name=None, resource_group=None):
    '''
    Reject the specified private endpoint connection associated with Azure Cosmos DB.
    '''
    return call_az("az cosmosdb private-endpoint-connection reject", locals())


def delete(account_name=None, id=None, name=None, resource_group=None):
    '''
    Delete the specified private endpoint connection associated with Azure Cosmos DB.
    '''
    return call_az("az cosmosdb private-endpoint-connection delete", locals())


def show(account_name=None, id=None, name=None, resource_group=None):
    '''
    Show details of a private endpoint connection associated with Azure Cosmos DB.
    '''
    return call_az("az cosmosdb private-endpoint-connection show", locals())




from .... pyaz_utils import call_az

def create(eventhub_name, name, namespace_name, resource_group, user_metadata=None):
    '''
    Creates the EventHub ConsumerGroup
    '''
    return call_az("az eventhubs eventhub consumer-group create", locals())


def show(eventhub_name, name, namespace_name, resource_group):
    '''
    Shows the ConsumerGroup Details
    '''
    return call_az("az eventhubs eventhub consumer-group show", locals())


def list(eventhub_name, namespace_name, resource_group, skip=None, top=None):
    '''
    List the ConsumerGroup by Eventhub
    '''
    return call_az("az eventhubs eventhub consumer-group list", locals())


def delete(eventhub_name, name, namespace_name, resource_group):
    '''
    Deletes the ConsumerGroup
    '''
    return call_az("az eventhubs eventhub consumer-group delete", locals())


def update(eventhub_name, name, namespace_name, resource_group, add=None, force_string=None, remove=None, set=None, user_metadata=None):
    '''
    Updates the EventHub ConsumerGroup
    '''
    return call_az("az eventhubs eventhub consumer-group update", locals())




from .. pyaz_utils import call_az
from . import dcos, kubernetes


def browse(name, resource_group, disable_browser=None, ssh_key_file=None):
    '''
    Show the dashboard for a service container's orchestrator in a web browser.
    '''
    return call_az("az acs browse", locals())


def create(name, resource_group, admin_password=None, admin_username=None, agent_count=None, agent_osdisk_size=None, agent_ports=None, agent_profiles=None, agent_storage_profile=None, agent_vm_size=None, agent_vnet_subnet_id=None, api_version=None, client_secret=None, deployment_name=None, dns_prefix=None, generate_ssh_keys=None, location=None, master_count=None, master_first_consecutive_static_ip=None, master_osdisk_size=None, master_profile=None, master_storage_profile=None, master_vm_size=None, master_vnet_subnet_id=None, no_wait=None, orchestrator_type=None, orchestrator_version=None, service_principal=None, ssh_key_value=None, tags=None, validate=None, windows=None):
    '''
    Create a new container service.
    '''
    return call_az("az acs create", locals())


def delete(name, resource_group, yes=None):
    '''
    Delete a container service.
    '''
    return call_az("az acs delete", locals())


def list(resource_group=None):
    '''
    List container services.
    '''
    return call_az("az acs list", locals())


def list_locations():
    '''
    List locations where Azure Container Service is in preview and in production.
    '''
    return call_az("az acs list-locations", locals())


def scale(name, new_agent_count, resource_group):
    '''
    Change the private agent count of a container service.
    '''
    return call_az("az acs scale", locals())


def show(name, resource_group):
    '''
    Show the details for a container service.
    '''
    return call_az("az acs show", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Wait for a container service to reach a desired state.
    '''
    return call_az("az acs wait", locals())




from ..... pyaz_utils import call_az
from . import recommendation


def show(column, name, resource_group, schema, table, workspace_name):
    '''
    Get the sensitivity classification of a given column.
    '''
    return call_az("az synapse sql pool classification show", locals())


def list(name, resource_group, workspace_name, filter=None):
    '''
    Get the sensitivity classifications of a given SQL pool.
    '''
    return call_az("az synapse sql pool classification list", locals())


def create(column, information_type, label, name, resource_group, schema, table, workspace_name):
    '''
    Create a column's sensitivity classification.
    '''
    return call_az("az synapse sql pool classification create", locals())


def delete(column, name, resource_group, schema, table, workspace_name):
    '''
    Delete the sensitivity classification of a given column.
    '''
    return call_az("az synapse sql pool classification delete", locals())


def update(column, name, resource_group, schema, table, workspace_name, information_type=None, label=None):
    '''
    Update a column's sensitivity classification.
    '''
    return call_az("az synapse sql pool classification update", locals())




from .... pyaz_utils import call_az

def set(name, resource_group, docker_custom_image_name=None, docker_registry_server_password=None, docker_registry_server_url=None, docker_registry_server_user=None, enable_app_service_storage=None, multicontainer_config_file=None, multicontainer_config_type=None, slot=None):
    '''
    Set an existing web app's container settings.
    '''
    return call_az("az webapp config container set", locals())


def delete(name, resource_group, slot=None):
    '''
    Delete an existing web app's container settings.
    '''
    return call_az("az webapp config container delete", locals())


def show(name, resource_group, show_multicontainer_config=None, slot=None):
    '''
    Get details of a web app's container settings.
    '''
    return call_az("az webapp config container show", locals())




from ... pyaz_utils import call_az
from . import terms


def list_offers(location, publisher, edge_zone=None):
    '''
    List the VM image offers available in the Azure Marketplace.
    '''
    return call_az("az vm image list-offers", locals())


def list_publishers(location, edge_zone=None):
    '''
    List the VM image publishers available in the Azure Marketplace.
    '''
    return call_az("az vm image list-publishers", locals())


def list_skus(location, offer, publisher, edge_zone=None):
    '''
    List the VM image SKUs available in the Azure Marketplace.
    '''
    return call_az("az vm image list-skus", locals())


def list(all=None, edge_zone=None, location=None, offer=None, publisher=None, sku=None):
    '''
    List the VM/VMSS images available in the Azure Marketplace.
    '''
    return call_az("az vm image list", locals())


def accept_terms(offer=None, plan=None, publisher=None, urn=None):
    '''
    Accept Azure Marketplace term so that the image can be used to create VMs
    '''
    return call_az("az vm image accept-terms", locals())


def show(edge_zone=None, location=None, offer=None, publisher=None, sku=None, urn=None, version=None):
    '''
    Get the details for a VM image available in the Azure Marketplace.
    '''
    return call_az("az vm image show", locals())




from .... pyaz_utils import call_az

def assign(name, identity_scope=None, resource_group=None, role=None, scope=None, system_assigned=None, user_assigned=None):
    '''
    Add a system assigned identity or a user assigned identity to a policy assignment.
    '''
    return call_az("az policy assignment identity assign", locals())


def show(name, resource_group=None, scope=None):
    '''
    Show a policy assignment's managed identity.
    '''
    return call_az("az policy assignment identity show", locals())


def remove(name, resource_group=None, scope=None):
    '''
    Remove a managed identity from a policy assignment.
    '''
    return call_az("az policy assignment identity remove", locals())




from ... pyaz_utils import call_az
from . import policy


def show(account_name, name, pool_name, resource_group, volume_name):
    '''
    Get the specified ANF snapshot.
    '''
    return call_az("az netappfiles snapshot show", locals())


def list(account_name, pool_name, resource_group, volume_name):
    '''
    List the snapshots of an ANF volume.
    '''
    return call_az("az netappfiles snapshot list", locals())


def delete(account_name, name, pool_name, resource_group, volume_name):
    '''
    Delete the specified ANF snapshot.
    '''
    return call_az("az netappfiles snapshot delete", locals())


def create(account_name, location, name, pool_name, resource_group, volume_name):
    '''
    Create a new Azure NetApp Files (ANF) snapshot.
    '''
    return call_az("az netappfiles snapshot create", locals())


def update(account_name, body, name, pool_name, resource_group, volume_name):
    return call_az("az netappfiles snapshot update", locals())




from ... pyaz_utils import call_az

def list(name, resource_group=None):
    '''
    List the deployment token for the static app.
    '''
    return call_az("az staticwebapp secrets list", locals())


def reset_api_key(name, no_wait=None, resource_group=None):
    '''
    Reset the deployment token for the static app.
    '''
    return call_az("az staticwebapp secrets reset-api-key", locals())




from ... pyaz_utils import call_az

def create(lock_type, name, namespace=None, notes=None, parent=None, resource=None, resource_group=None, resource_type=None):
    '''
    Create a resource-level lock.
    '''
    return call_az("az resource lock create", locals())


def delete(ids=None, name=None, namespace=None, parent=None, resource=None, resource_group=None, resource_type=None):
    '''
    Delete a resource-level lock.
    '''
    return call_az("az resource lock delete", locals())


def list(filter_string=None, namespace=None, parent=None, resource=None, resource_group=None, resource_type=None):
    '''
    List lock information in the resource-level.
    '''
    return call_az("az resource lock list", locals())


def show(ids=None, name=None, namespace=None, parent=None, resource=None, resource_group=None, resource_type=None):
    '''
    Show the details of a resource-level lock
    '''
    return call_az("az resource lock show", locals())


def update(ids=None, lock_type=None, name=None, namespace=None, notes=None, parent=None, resource=None, resource_group=None, resource_type=None):
    '''
    Update a resource-level lock.
    '''
    return call_az("az resource lock update", locals())




from .... pyaz_utils import call_az

def disable(name, resource_group):
    '''
    Disable Azure Active Directly only Authentication for this Managed Instance.
    '''
    return call_az("az sql mi ad-only-auth disable", locals())


def enable(name, resource_group):
    '''
    Enable Azure Active Directly only Authentication for this Managed Instance.
    '''
    return call_az("az sql mi ad-only-auth enable", locals())


def get(name, resource_group):
    '''
    Get a specific Azure Active Directly only Authentication property.
    '''
    return call_az("az sql mi ad-only-auth get", locals())




from ... pyaz_utils import call_az

def browse(name, resource_group, disable_browser=None, ssh_key_file=None):
    return call_az("az acs dcos browse", locals())


def install_cli(client_version=None, install_location=None):
    '''
    Download and install the DC/OS command-line tool for a cluster.
    '''
    return call_az("az acs dcos install-cli", locals())




from .... pyaz_utils import call_az

def show(account_name, resource_group=None):
    '''
    Show the properties of a storage account's blob service.
    '''
    return call_az("az storage account blob-service-properties show", locals())


def update(account_name, add=None, change_feed_retention_days=None, container_delete_retention_days=None, default_service_version=None, delete_retention_days=None, enable_change_feed=None, enable_container_delete_retention=None, enable_delete_retention=None, enable_last_access_tracking=None, enable_restore_policy=None, enable_versioning=None, force_string=None, remove=None, resource_group=None, restore_days=None, set=None):
    '''
    Update the properties of a storage account's blob service.
    '''
    return call_az("az storage account blob-service-properties update", locals())




from ... pyaz_utils import call_az

def list(plan, resource_group):
    '''
    list the virtual network integrations used in an appservice plan
    '''
    return call_az("az appservice vnet-integration list", locals())




from .... pyaz_utils import call_az

def show(resource_group, workspace_name):
    '''
    Get the SQL Azure Active Directory administrator.
    '''
    return call_az("az synapse sql ad-admin show", locals())


def create(display_name, object_id, resource_group, workspace_name, no_wait=None):
    '''
    Create the SQL Azure Active Directory administrator.
    '''
    return call_az("az synapse sql ad-admin create", locals())


def update(resource_group, workspace_name, add=None, display_name=None, force_string=None, no_wait=None, object_id=None, remove=None, set=None):
    '''
    Update the SQL Azure Active Directory administrator.
    '''
    return call_az("az synapse sql ad-admin update", locals())


def delete(resource_group, workspace_name, no_wait=None, yes=None):
    '''
    Delete the SQL Azure Active Directory administrator.
    '''
    return call_az("az synapse sql ad-admin delete", locals())


def wait(resource_group, workspace_name, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition is met.
    '''
    return call_az("az synapse sql ad-admin wait", locals())




from .... pyaz_utils import call_az

def start(destination_path, destination_share, account_key=None, account_name=None, connection_string=None, file_snapshot=None, metadata=None, sas_token=None, source_account_key=None, source_account_name=None, source_blob=None, source_container=None, source_path=None, source_sas=None, source_share=None, source_snapshot=None, source_uri=None, timeout=None):
    '''
    Copy a file asynchronously.
    '''
    return call_az("az storage file copy start", locals())


def cancel(copy_id, destination_path, destination_share, account_key=None, account_name=None, connection_string=None, sas_token=None, timeout=None):
    return call_az("az storage file copy cancel", locals())


def start_batch(account_key=None, account_name=None, connection_string=None, destination_path=None, destination_share=None, dryrun=None, metadata=None, pattern=None, sas_token=None, source_account_key=None, source_account_name=None, source_client=None, source_container=None, source_sas=None, source_share=None, source_uri=None, timeout=None):
    '''
    Copy multiple files or blobs to a file share.
    '''
    return call_az("az storage file copy start-batch", locals())




from .. pyaz_utils import call_az

def create(name, resource_group, accelerated_network=None, copy_start=None, disk_access=None, disk_encryption_set=None, edge_zone=None, encryption_type=None, for_upload=None, hyper_v_generation=None, incremental=None, location=None, network_access_policy=None, no_wait=None, public_network_access=None, size_gb=None, sku=None, source=None, source_storage_account_id=None, tags=None):
    '''
    Create a snapshot.
    '''
    return call_az("az snapshot create", locals())


def delete(name, resource_group):
    return call_az("az snapshot delete", locals())


def grant_access(duration_in_seconds, name, resource_group, access_level=None):
    '''
    Grant read access to a snapshot.
    '''
    return call_az("az snapshot grant-access", locals())


def list(resource_group=None):
    '''
    List snapshots.
    '''
    return call_az("az snapshot list", locals())


def revoke_access(name, resource_group):
    '''
    Revoke read access to a snapshot.
    '''
    return call_az("az snapshot revoke-access", locals())


def show(name, resource_group):
    return call_az("az snapshot show", locals())


def update(name, resource_group, accelerated_network=None, add=None, disk_access=None, disk_encryption_set=None, encryption_type=None, force_string=None, network_access_policy=None, no_wait=None, public_network_access=None, remove=None, set=None, sku=None):
    '''
    Update a snapshot.
    '''
    return call_az("az snapshot update", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of a snapshot is met.
    '''
    return call_az("az snapshot wait", locals())




from .... pyaz_utils import call_az

def merge(file, name, vault_name, certificate_attributes=None, disabled=None, expires=None, not_before=None, tags=None):
    return call_az("az keyvault certificate pending merge", locals())


def show(name, vault_name):
    return call_az("az keyvault certificate pending show", locals())


def delete(name, vault_name):
    return call_az("az keyvault certificate pending delete", locals())




from .... pyaz_utils import call_az
from . import event_channel, key


def show(name, resource_group):
    '''
    Get the details of a partner namespace.
    '''
    return call_az("az eventgrid partner namespace show", locals())


def delete(name, resource_group, yes=None):
    '''
    Delete a partner namespace.
    '''
    return call_az("az eventgrid partner namespace delete", locals())


def list(odata_query=None, resource_group=None):
    '''
    List available partner namespaces.
    '''
    return call_az("az eventgrid partner namespace list", locals())


def create(name, partner_registration_id, resource_group, location=None, tags=None):
    '''
    Create a partner namespace.
    '''
    return call_az("az eventgrid partner namespace create", locals())




from .... pyaz_utils import call_az

def create(name, resource_group, vm, capture_limit=None, capture_size=None, file_path=None, filters=None, storage_account=None, storage_path=None, time_limit=None):
    '''
    Create and start a packet capture session.
    '''
    return call_az("az network watcher packet-capture create", locals())


def show(location, name, network_watcher_name=None):
    '''
    Show details of a packet capture session.
    '''
    return call_az("az network watcher packet-capture show", locals())


def show_status(location, name, network_watcher_name=None):
    '''
    Show the status of a packet capture session.
    '''
    return call_az("az network watcher packet-capture show-status", locals())


def delete(location, name, network_watcher_name=None):
    '''
    Delete a packet capture session.
    '''
    return call_az("az network watcher packet-capture delete", locals())


def stop(location, name, network_watcher_name=None):
    '''
    Stop a running packet capture session.
    '''
    return call_az("az network watcher packet-capture stop", locals())


def list(location, network_watcher_name=None):
    '''
    List all packet capture sessions within a resource group.
    '''
    return call_az("az network watcher packet-capture list", locals())




from .... pyaz_utils import call_az

def list(elastic_pool, resource_group, server):
    return call_az("az sql elastic-pool op list", locals())


def cancel(elastic_pool, name, resource_group, server):
    return call_az("az sql elastic-pool op cancel", locals())




from .... pyaz_utils import call_az

def delete(name, resource_group, service_name):
    '''
    Delete a private link service endpoint connection.
    '''
    return call_az("az network private-link-service connection delete", locals())


def update(connection_status, name, resource_group, service_name, action_required=None, description=None):
    '''
    Update a private link service endpoint connection.
    '''
    return call_az("az network private-link-service connection update", locals())




from .... pyaz_utils import call_az

def list(experiment, job, resource_group, workspace):
    '''
    List remote login information for nodes which executed the job.
    '''
    return call_az("az batchai job node list", locals())


def exec(experiment, job, resource_group, workspace, address=None, exec=None, node_id=None, password=None, ssh_private_key=None):
    '''
    Executes a command line on a cluster's node used to execute the job with optional ports forwarding.
    '''
    return call_az("az batchai job node exec", locals())




from ... pyaz_utils import call_az

def list():
    '''
    List the external security solutions.
    '''
    return call_az("az security external-security-solution list", locals())


def show(name, resource_group):
    '''
    Shows an external security solution.
    '''
    return call_az("az security external-security-solution show", locals())




from ... pyaz_utils import call_az

def show():
    return call_az("az ad signed-in-user show", locals())


def list_owned_objects(type=None):
    '''
    Get the list of directory objects that are owned by the user
    '''
    return call_az("az ad signed-in-user list-owned-objects", locals())




from ... pyaz_utils import call_az

def show(account_name, name, resource_group, transform_name):
    '''
    Show the details of a job.
    '''
    return call_az("az ams job show", locals())


def list(account_name, resource_group, transform_name, filter=None, orderby=None):
    '''
    List all the jobs of a transform within an Azure Media Services account.
    '''
    return call_az("az ams job list", locals())


def delete(account_name, name, resource_group, transform_name):
    '''
    Delete a job.
    '''
    return call_az("az ams job delete", locals())


def cancel(account_name, name, resource_group, transform_name, delete=None):
    '''
    Cancel a job.
    '''
    return call_az("az ams job cancel", locals())


def start(account_name, name, output_assets, resource_group, transform_name, base_uri=None, correlation_data=None, description=None, files=None, input_asset_name=None, label=None, priority=None):
    '''
    Start a job.
    '''
    return call_az("az ams job start", locals())


def update(account_name, name, resource_group, transform_name, add=None, description=None, force_string=None, priority=None, remove=None, set=None):
    '''
    Update an existing job.
    '''
    return call_az("az ams job update", locals())




from .... pyaz_utils import call_az

def show(name, resource, resource_group=None, resource_namespace=None, resource_parent=None, resource_type=None):
    return call_az("az monitor diagnostic-settings categories show", locals())


def list(resource, resource_group=None, resource_namespace=None, resource_parent=None, resource_type=None):
    '''
    List the diagnostic settings categories for the specified resource.
    '''
    return call_az("az monitor diagnostic-settings categories list", locals())




from .. pyaz_utils import call_az

def list():
    '''
    List the contents of the object cache.
    '''
    return call_az("az cache list", locals())


def show(name, resource_group, resource_type):
    '''
    Show the contents of a specific object in the cache.
    '''
    return call_az("az cache show", locals())


def delete(name, resource_group, resource_type):
    '''
    Delete an object from the cache.
    '''
    return call_az("az cache delete", locals())


def purge():
    '''
    Clear the entire CLI object cache.
    '''
    return call_az("az cache purge", locals())




from ..... pyaz_utils import call_az

def show(name, resource_group, zone_name, record_type=None):
    '''
    Get the details of an AAAA record set.
    '''
    return call_az("az network private-dns record-set aaaa show", locals())


def delete(name, resource_group, zone_name, if_match=None, record_type=None, yes=None):
    '''
    Delete an AAAA record set and all associated records.
    '''
    return call_az("az network private-dns record-set aaaa delete", locals())


def list(resource_group, zone_name, record_type=None):
    '''
    List all AAAA record sets in a zone.
    '''
    return call_az("az network private-dns record-set aaaa list", locals())


def create(name, resource_group, zone_name, metadata=None, record_type=None, ttl=None):
    '''
    Create an empty AAAA record set.
    '''
    return call_az("az network private-dns record-set aaaa create", locals())


def add_record(ipv6_address, record_set_name, resource_group, zone_name):
    '''
    Add an AAAA record.
    '''
    return call_az("az network private-dns record-set aaaa add-record", locals())


def remove_record(ipv6_address, record_set_name, resource_group, zone_name, keep_empty_record_set=None):
    '''
    Remove AAAA record from its record set.
    '''
    return call_az("az network private-dns record-set aaaa remove-record", locals())


def update(name, resource_group, zone_name, add=None, force_string=None, if_match=None, metadata=None, record_type=None, remove=None, set=None):
    '''
    Update an AAAA record set.
    '''
    return call_az("az network private-dns record-set aaaa update", locals())




from .... pyaz_utils import call_az
from . import connection, peer_connection


def create(circuit_name, peer_asn, peering_type, primary_peer_subnet, resource_group, secondary_peer_subnet, vlan_id, advertised_public_prefixes=None, customer_asn=None, ip_version=None, legacy_mode=None, route_filter=None, routing_registry_name=None, shared_key=None):
    '''
    Create peering settings for an ExpressRoute circuit.
    '''
    return call_az("az network express-route peering create", locals())


def delete(circuit_name, name, resource_group):
    '''
    Delete peering settings.
    '''
    return call_az("az network express-route peering delete", locals())


def show(circuit_name, name, resource_group):
    '''
    Get the details of an express route peering.
    '''
    return call_az("az network express-route peering show", locals())


def list(circuit_name, resource_group):
    '''
    List peering settings of an ExpressRoute circuit.
    '''
    return call_az("az network express-route peering list", locals())


def get_stats(circuit_name, name, resource_group):
    '''
    Get all traffic stats of an ExpressRoute peering.
    '''
    return call_az("az network express-route peering get-stats", locals())


def update(circuit_name, name, resource_group, add=None, advertised_public_prefixes=None, customer_asn=None, force_string=None, ip_version=None, legacy_mode=None, peer_asn=None, primary_peer_subnet=None, remove=None, route_filter=None, routing_registry_name=None, secondary_peer_subnet=None, set=None, shared_key=None, vlan_id=None):
    '''
    Update peering settings of an ExpressRoute circuit.
    '''
    return call_az("az network express-route peering update", locals())




from ... pyaz_utils import call_az

def show(name, node_name, resource_group, workspace_name):
    '''
    Get self-hosted integration runtime node information.
    '''
    return call_az("az synapse integration-runtime-node show", locals())


def update(auto_update, name, node_name, resource_group, update_delay_offset, workspace_name):
    '''
    Update self-hosted integration runtime node.
    '''
    return call_az("az synapse integration-runtime-node update", locals())


def delete(name, node_name, resource_group, workspace_name, yes=None):
    '''
    Remove a self-hosted integration runtime node.
    '''
    return call_az("az synapse integration-runtime-node delete", locals())


def get_ip_address(name, node_name, resource_group, workspace_name):
    '''
    Get self-hosted integration runtime node ip.
    '''
    return call_az("az synapse integration-runtime-node get-ip-address", locals())




from ..... pyaz_utils import call_az

def delete(name, resource_group, zone_name, if_match=None, no_wait=None, yes=None):
    '''
    Delete a virtual network link to the specified Private DNS zone.
    '''
    return call_az("az network private-dns link vnet delete", locals())


def show(name, resource_group, zone_name):
    '''
    Get a virtual network link to the specified Private DNS zone.
    '''
    return call_az("az network private-dns link vnet show", locals())


def list(resource_group, zone_name, top=None):
    '''
    List the virtual network links to the specified Private DNS zone.
    '''
    return call_az("az network private-dns link vnet list", locals())


def create(name, registration_enabled, resource_group, virtual_network, zone_name, no_wait=None, tags=None):
    '''
    Create a virtual network link to the specified Private DNS zone.
    '''
    return call_az("az network private-dns link vnet create", locals())


def update(name, resource_group, zone_name, add=None, force_string=None, if_match=None, no_wait=None, registration_enabled=None, remove=None, set=None, tags=None):
    '''
    Update a virtual network link's properties. Does not modify virtual network within the link.
    '''
    return call_az("az network private-dns link vnet update", locals())


def wait(name, resource_group, zone_name, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the virtual network link to the specified Private DNS zone is met.
    '''
    return call_az("az network private-dns link vnet wait", locals())




from ..... pyaz_utils import call_az

def show(name, resource_group, security_alert_policy_name, workspace_name):
    '''
    Get a SQL pool's threat detection policy.
    '''
    return call_az("az synapse sql pool threat-policy show", locals())


def update(name, resource_group, workspace_name, add=None, disabled_alerts=None, email_account_admins=None, email_addresses=None, force_string=None, remove=None, retention_days=None, security_alert_policy_name=None, set=None, state=None, storage_account=None, storage_endpoint=None, storage_key=None):
    '''
    Update a SQL pool's threat detection policy.
    '''
    return call_az("az synapse sql pool threat-policy update", locals())




from ..... pyaz_utils import call_az

def add(gateway_name, name, private_link, resource_group, ip_address=None, no_wait=None, primary=None):
    '''
    Add an IP configuration to a Private Link to scale up its capability
    '''
    return call_az("az network application-gateway private-link ip-config add", locals())


def remove(gateway_name, name, private_link, resource_group, no_wait=None, yes=None):
    '''
    Remove an IP configuration from a Private Link to scale down its capability
    '''
    return call_az("az network application-gateway private-link ip-config remove", locals())


def show(gateway_name, name, private_link, resource_group):
    '''
    Show an IP configuration of a Private Link
    '''
    return call_az("az network application-gateway private-link ip-config show", locals())


def list(gateway_name, private_link, resource_group):
    '''
    List all the IP configuration of a Private Link
    '''
    return call_az("az network application-gateway private-link ip-config list", locals())


def wait(gateway_name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until the condition of corresponding application gateway is met
    '''
    return call_az("az network application-gateway private-link ip-config wait", locals())




from ... pyaz_utils import call_az

def list(resource_group, service_name):
    return call_az("az search shared-private-link-resource list", locals())


def show(name, resource_group, service_name):
    return call_az("az search shared-private-link-resource show", locals())


def delete(name, resource_group, service_name, yes=None):
    return call_az("az search shared-private-link-resource delete", locals())


def create(group_id, name, resource_group, resource_id, service_name, no_wait=None, request_message=None):
    return call_az("az search shared-private-link-resource create", locals())


def update(group_id, name, request_message, resource_group, resource_id, service_name, no_wait=None):
    return call_az("az search shared-private-link-resource update", locals())


def wait(name, resource_group, service_name, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Wait for async shared private link resource operations.
    '''
    return call_az("az search shared-private-link-resource wait", locals())




from ..... pyaz_utils import call_az

def list(resource_group, workspace_name):
    '''
    List all the intelligence packs possible and whether they are enabled or disabled for a given workspace.
    '''
    return call_az("az monitor log-analytics workspace pack list", locals())


def enable(name, resource_group, workspace_name):
    '''
    Enable an intelligence pack for a given workspace.
    '''
    return call_az("az monitor log-analytics workspace pack enable", locals())


def disable(name, resource_group, workspace_name):
    '''
    Disable an intelligence pack for a given workspace.
    '''
    return call_az("az monitor log-analytics workspace pack disable", locals())




from ... pyaz_utils import call_az

def create(name, public_ip_address, resource_group, vnet_name, location=None, scale_units=None, sku=None, tags=None):
    '''
    Create a Azure bastion host machine.
    '''
    return call_az("az network bastion create", locals())


def show(name, resource_group):
    '''
    Show a Azure bastion host machine.
    '''
    return call_az("az network bastion show", locals())


def list(resource_group=None):
    '''
    List all Azure bastion host machines.
    '''
    return call_az("az network bastion list", locals())


def ssh(auth_type, name, resource_group, target_resource_id, resource_port=None, ssh_key=None, username=None):
    '''
    SSH to a virtual machine using Tunneling from Azure Bastion.
    '''
    return call_az("az network bastion ssh", locals())


def rdp(name, resource_group, target_resource_id, resource_port=None):
    '''
    RDP to target Virtual Machine using Tunneling from Azure Bastion.
    '''
    return call_az("az network bastion rdp", locals())


def tunnel(name, port, resource_group, resource_port, target_resource_id, timeout=None):
    '''
    Show a Azure bastion host machine.
    '''
    return call_az("az network bastion tunnel", locals())


def delete(name, resource_group):
    '''
    Delete a Azure bastion host machine.
    '''
    return call_az("az network bastion delete", locals())




from ... pyaz_utils import call_az
from . import alert


def list(caller=None, correlation_id=None, end_time=None, filters=None, max_events=None, namespace=None, offset=None, resource_group=None, resource_id=None, select=None, start_time=None, status=None):
    '''
    List and query activity log events.
    '''
    return call_az("az monitor activity-log list", locals())


def list_categories():
    '''
    List the event categories of activity logs.
    '''
    return call_az("az monitor activity-log list-categories", locals())




from ..... pyaz_utils import call_az

def create(gateway_name, name, path_map_name, paths, resource_group, address_pool=None, http_settings=None, no_wait=None, redirect_config=None, rewrite_rule_set=None, waf_policy=None):
    '''
    Create a rule for a URL path map.
    '''
    return call_az("az network application-gateway url-path-map rule create", locals())


def delete(gateway_name, name, path_map_name, resource_group, no_wait=None):
    '''
    Delete a rule of a URL path map.
    '''
    return call_az("az network application-gateway url-path-map rule delete", locals())




from ... pyaz_utils import call_az

def list(name, password=None, resource_group=None, suffix=None, top=None, username=None):
    '''
    List repositories in an Azure Container Registry.
    '''
    return call_az("az acr repository list", locals())


def show_tags(name, repository, detail=None, orderby=None, password=None, resource_group=None, suffix=None, top=None, username=None):
    '''
    Show tags for a repository in an Azure Container Registry.
    '''
    return call_az("az acr repository show-tags", locals())


def show_manifests(name, repository, detail=None, orderby=None, password=None, resource_group=None, suffix=None, top=None, username=None):
    '''
    Show manifests of a repository in an Azure Container Registry.
    '''
    return call_az("az acr repository show-manifests", locals())


def show(name, image=None, password=None, repository=None, resource_group=None, suffix=None, username=None):
    '''
    Get the attributes of a repository or image in an Azure Container Registry.
    '''
    return call_az("az acr repository show", locals())


def update(name, delete_enabled=None, image=None, list_enabled=None, password=None, read_enabled=None, repository=None, resource_group=None, suffix=None, username=None, write_enabled=None):
    '''
    Update the attributes of a repository or image in an Azure Container Registry.
    '''
    return call_az("az acr repository update", locals())


def delete(name, image=None, password=None, repository=None, resource_group=None, suffix=None, username=None, yes=None):
    '''
    Delete a repository or image in an Azure Container Registry.
    '''
    return call_az("az acr repository delete", locals())


def untag(image, name, password=None, resource_group=None, suffix=None, username=None):
    '''
    Untag an image in an Azure Container Registry.
    '''
    return call_az("az acr repository untag", locals())




from ... pyaz_utils import call_az

def list():
    '''
    List all security assessment results.
    '''
    return call_az("az security assessment-metadata list", locals())


def show(name):
    '''
    Shows a security assessment.
    '''
    return call_az("az security assessment-metadata show", locals())


def create(description, display_name, name, severity, remediation_description=None):
    '''
    Creates a customer managed security assessment type.
    '''
    return call_az("az security assessment-metadata create", locals())


def delete(name):
    '''
    Deletes a security assessment type and all it's assessment results.
    '''
    return call_az("az security assessment-metadata delete", locals())




from .... pyaz_utils import call_az
from . import connection


def create(name, resource_group, location=None, max_val=None, min_val=None, tags=None, virtual_hub=None):
    '''
    Create an ExpressRoute gateway.
    '''
    return call_az("az network express-route gateway create", locals())


def delete(name, resource_group):
    '''
    Delete an ExpressRoute gateway.
    '''
    return call_az("az network express-route gateway delete", locals())


def list(resource_group=None):
    '''
    List ExpressRoute gateways.
    '''
    return call_az("az network express-route gateway list", locals())


def show(name, resource_group):
    '''
    Get the details of an ExpressRoute gateway.
    '''
    return call_az("az network express-route gateway show", locals())


def update(name, resource_group, add=None, force_string=None, max_val=None, min_val=None, remove=None, set=None, tags=None):
    '''
    Update settings of an ExpressRoute gateway.
    '''
    return call_az("az network express-route gateway update", locals())




from .... pyaz_utils import call_az

def create(address_prefix, name, next_hop_type, resource_group, route_table_name, next_hop_ip_address=None):
    '''
    Create a route in a route table.
    '''
    return call_az("az network route-table route create", locals())


def delete(name, resource_group, route_table_name):
    '''
    Delete a route from a route table.
    '''
    return call_az("az network route-table route delete", locals())


def show(name, resource_group, route_table_name):
    '''
    Get the details of a route in a route table.
    '''
    return call_az("az network route-table route show", locals())


def list(resource_group, route_table_name):
    '''
    List routes in a route table.
    '''
    return call_az("az network route-table route list", locals())


def update(name, resource_group, route_table_name, add=None, address_prefix=None, force_string=None, next_hop_ip_address=None, next_hop_type=None, remove=None, set=None):
    '''
    Update a route in a route table.
    '''
    return call_az("az network route-table route update", locals())




from ... pyaz_utils import call_az

def add(allowed_origins, name, resource_group):
    '''
    Add allowed origins to a SignalR Service
    '''
    return call_az("az signalr cors add", locals())


def remove(allowed_origins, name, resource_group):
    '''
    Remove allowed origins from a SignalR Service
    '''
    return call_az("az signalr cors remove", locals())


def list(name, resource_group):
    '''
    List allowed origins of a SignalR Service
    '''
    return call_az("az signalr cors list", locals())


def update(allowed_origins, name, resource_group):
    '''
    Update allowed origins to a SignalR Service
    '''
    return call_az("az signalr cors update", locals())




from .. pyaz_utils import call_az

def create(name, resource_group, location=None, no_wait=None, tags=None):
    '''
    Create a disk access resource.
    '''
    return call_az("az disk-access create", locals())


def update(name, resource_group, add=None, force_string=None, no_wait=None, remove=None, set=None, tags=None):
    '''
    Update a disk access resource.
    '''
    return call_az("az disk-access update", locals())


def show(name, resource_group):
    '''
    Get information of a disk access resource.
    '''
    return call_az("az disk-access show", locals())


def list(resource_group=None):
    '''
    List disk access resources.
    '''
    return call_az("az disk-access list", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of a disk access is met.
    '''
    return call_az("az disk-access wait", locals())


def delete(name, resource_group):
    '''
    Delete a disk access resource.
    '''
    return call_az("az disk-access delete", locals())




from .. pyaz_utils import call_az
from . import auth, config, connection, cors, deleted, hybrid_connection, identity, log, traffic_routing, vnet_integration


def create(name, plan, resource_group, assign_identity=None, deployment_container_image_name=None, deployment_local_git=None, deployment_source_branch=None, deployment_source_url=None, docker_registry_server_password=None, docker_registry_server_user=None, multicontainer_config_file=None, multicontainer_config_type=None, role=None, runtime=None, scope=None, startup_file=None, subnet=None, tags=None, vnet=None):
    '''
    Create a web app.
    '''
    return call_az("az webapp create", locals())


def up(app_service_environment=None, dryrun=None, html=None, launch_browser=None, location=None, logs=None, name=None, os_type=None, plan=None, resource_group=None, runtime=None, sku=None):
    '''
    Create a webapp and deploy code from a local workspace to the app. The command is required to run from the folder where the code is present. Current support includes Node, Python, .NET Core and ASP.NET. Node, Python apps are created as Linux apps. .Net Core, ASP.NET, and static HTML apps are created as Windows apps. Append the html flag to deploy as a static HTML app.

    '''
    return call_az("az webapp up", locals())


def ssh(name, resource_group, instance=None, port=None, slot=None, timeout=None):
    '''
    SSH command establishes a ssh session to the web container and developer would get a shell terminal remotely.
    '''
    return call_az("az webapp ssh", locals())


def list(resource_group=None):
    '''
    List web apps.
    '''
    return call_az("az webapp list", locals())


def show(name, resource_group, slot=None):
    '''
    Get the details of a web app.
    '''
    return call_az("az webapp show", locals())


def delete(name, resource_group, keep_dns_registration=None, keep_empty_plan=None, keep_metrics=None, slot=None):
    '''
    Delete a web app.
    '''
    return call_az("az webapp delete", locals())


def stop(name, resource_group, slot=None):
    '''
    Stop a web app.
    '''
    return call_az("az webapp stop", locals())


def start(name, resource_group, slot=None):
    '''
    Start a web app.
    '''
    return call_az("az webapp start", locals())


def restart(name, resource_group, slot=None):
    '''
    Restart a web app.
    '''
    return call_az("az webapp restart", locals())


def browse(name, resource_group, logs=None, slot=None):
    '''
    Open a web app in a browser.
    '''
    return call_az("az webapp browse", locals())


def list_instances(name, resource_group, slot=None):
    '''
    List all scaled out instances of a web app or web app slot.
    '''
    return call_az("az webapp list-instances", locals())


def list_runtimes(linux=None):
    '''
    List available built-in stacks which can be used for web apps.
    '''
    return call_az("az webapp list-runtimes", locals())


def create_remote_connection(name, resource_group, instance=None, port=None, slot=None, timeout=None):
    '''
    Creates a remote connection using a tcp tunnel to your web app
    '''
    return call_az("az webapp create-remote-connection", locals())


def deploy(name, resource_group, async_=None, clean=None, ignore_stack=None, restart=None, slot=None, src_path=None, src_url=None, target_path=None, timeout=None, type=None):
    '''
    Deploys a provided artifact to Azure Web Apps.
    '''
    return call_az("az webapp deploy", locals())


def update(name, resource_group, add=None, client_affinity_enabled=None, force_dns_registration=None, force_string=None, https_only=None, remove=None, set=None, skip_custom_domain_verification=None, skip_dns_registration=None, slot=None, ttl_in_seconds=None):
    '''
    Update an existing web app.
    '''
    return call_az("az webapp update", locals())




from ... pyaz_utils import call_az
from . import file, subtask


def create(job_id, account_endpoint=None, account_key=None, account_name=None, affinity_id=None, application_package_references=None, command_line=None, environment_settings=None, json_file=None, max_task_retry_count=None, max_wall_clock_time=None, resource_files=None, retention_time=None, task_id=None):
    '''
    Create Batch tasks.
    '''
    return call_az("az batch task create", locals())


def list(job_id, account_endpoint=None, account_key=None, account_name=None, expand=None, filter=None, select=None):
    return call_az("az batch task list", locals())


def delete(job_id, task_id, account_endpoint=None, account_key=None, account_name=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None, yes=None):
    return call_az("az batch task delete", locals())


def show(job_id, task_id, account_endpoint=None, account_key=None, account_name=None, expand=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None, select=None):
    return call_az("az batch task show", locals())


def reset(job_id, task_id, account_endpoint=None, account_key=None, account_name=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None, json_file=None, max_task_retry_count=None, max_wall_clock_time=None, retention_time=None):
    '''
    Reset the properties of a Batch task.
    '''
    return call_az("az batch task reset", locals())


def reactivate(job_id, task_id, account_endpoint=None, account_key=None, account_name=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None):
    return call_az("az batch task reactivate", locals())


def stop(job_id, task_id, account_endpoint=None, account_key=None, account_name=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None):
    return call_az("az batch task stop", locals())




from ... pyaz_utils import call_az

def assign(name, resource_group, identities=None, role=None, scope=None):
    '''
    Enable managed service identity on a VM.
    '''
    return call_az("az vm identity assign", locals())


def remove(name, resource_group, identities=None):
    '''
    Remove managed service identities from a VM.
    '''
    return call_az("az vm identity remove", locals())


def show(name, resource_group):
    '''
    display VM's managed identity info.
    '''
    return call_az("az vm identity show", locals())




from .... pyaz_utils import call_az

def create(account_name, policy, resource_group=None):
    '''
    Create Blob Inventory Policy for storage account.
    '''
    return call_az("az storage account blob-inventory-policy create", locals())


def update(account_name, add=None, force_string=None, remove=None, resource_group=None, set=None):
    '''
    Update Blob Inventory Policy associated with the specified storage account.
    '''
    return call_az("az storage account blob-inventory-policy update", locals())


def delete(account_name, resource_group=None, yes=None):
    '''
    Delete Blob Inventory Policy associated with the specified storage account.
    '''
    return call_az("az storage account blob-inventory-policy delete", locals())


def show(account_name, resource_group=None):
    '''
    Show Blob Inventory Policy properties associated with the specified storage account.
    '''
    return call_az("az storage account blob-inventory-policy show", locals())




from .... pyaz_utils import call_az

def create(endpoint_name, hub_name, route_name, source_type, condition=None, enabled=None, resource_group=None):
    '''
    Create a route in IoT Hub.
    '''
    return call_az("az iot hub route create", locals())


def show(hub_name, route_name, resource_group=None):
    '''
    Get information about the route in IoT Hub.
    '''
    return call_az("az iot hub route show", locals())


def list(hub_name, resource_group=None, source_type=None):
    '''
    Get all the routes in IoT Hub.
    '''
    return call_az("az iot hub route list", locals())


def delete(hub_name, resource_group=None, route_name=None, source_type=None):
    '''
    Delete all or mentioned route for your IoT Hub.
    '''
    return call_az("az iot hub route delete", locals())


def update(hub_name, route_name, condition=None, enabled=None, endpoint_name=None, resource_group=None, source_type=None):
    '''
    Update a route in IoT Hub.
    '''
    return call_az("az iot hub route update", locals())


def test(hub_name, app_properties=None, body=None, resource_group=None, route_name=None, source_type=None, system_properties=None):
    '''
    Test all routes or mentioned route in IoT Hub.
    '''
    return call_az("az iot hub route test", locals())




from ... pyaz_utils import call_az
from . import operation, release, revision, versionset


def import_(path, resource_group, service_name, specification_format, api_id=None, api_revision=None, api_type=None, api_version=None, api_version_set_id=None, description=None, display_name=None, no_wait=None, protocols=None, service_url=None, soap_api_type=None, specification_path=None, specification_url=None, subscription_key_header_name=None, subscription_key_query_param_name=None, subscription_required=None, wsdl_endpoint_name=None, wsdl_service_name=None):
    '''
    Import an API Management API.
    '''
    return call_az("az apim api import", locals())


def create(api_id, display_name, path, resource_group, service_name, api_type=None, authorization_scope=None, authorization_server_id=None, bearer_token_sending_methods=None, description=None, no_wait=None, open_id_provider_id=None, protocols=None, service_url=None, subscription_key_header_name=None, subscription_key_query_param_name=None, subscription_key_required=None, subscription_required=None):
    '''
    Create an API Management API.
    '''
    return call_az("az apim api create", locals())


def show(api_id, resource_group, service_name):
    '''
    Show details of an API Management API.
    '''
    return call_az("az apim api show", locals())


def list(resource_group, service_name, filter_display_name=None, skip=None, top=None):
    '''
    List API Management API's.
    '''
    return call_az("az apim api list", locals())


def delete(api_id, resource_group, service_name, delete_revisions=None, if_match=None, no_wait=None, yes=None):
    '''
    Delete an API Management API.
    '''
    return call_az("az apim api delete", locals())


def update(api_id, resource_group, service_name, add=None, api_type=None, description=None, display_name=None, force_string=None, if_match=None, no_wait=None, path=None, protocols=None, remove=None, service_url=None, set=None, subscription_key_header_name=None, subscription_key_query_param_name=None, subscription_required=None, tags=None):
    '''
    Update an API Management API.
    '''
    return call_az("az apim api update", locals())


def wait(api_id, name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of an apim api is met.
    '''
    return call_az("az apim api wait", locals())




from ... pyaz_utils import call_az

def create(name, resource_group, app_service_environment=None, hyper_v=None, is_linux=None, location=None, no_wait=None, number_of_workers=None, per_site_scaling=None, sku=None, tags=None, zone_redundant=None):
    '''
    Create an app service plan.
    '''
    return call_az("az appservice plan create", locals())


def delete(name, resource_group, yes=None):
    '''
    Delete an app service plan.
    '''
    return call_az("az appservice plan delete", locals())


def list(resource_group=None):
    '''
    List app service plans.
    '''
    return call_az("az appservice plan list", locals())


def show(name, resource_group):
    '''
    Get the app service plans for a resource group or a set of resource groups.
    '''
    return call_az("az appservice plan show", locals())


def update(name, resource_group, add=None, force_string=None, no_wait=None, number_of_workers=None, remove=None, set=None, sku=None):
    '''
    Update an app service plan.
    '''
    return call_az("az appservice plan update", locals())




from ... pyaz_utils import call_az

def list(subscription_id):
    '''
    Get list of applicable reservation order ids.
    '''
    return call_az("az reservations reservation-order-id list", locals())




from ..... pyaz_utils import call_az

def add(connection_monitor, location, name, protocol, test_groups, frequency=None, http_method=None, http_path=None, http_port=None, http_prefer_https=None, http_request_header=None, http_valid_status_codes=None, icmp_disable_trace_route=None, preferred_ip_version=None, tcp_disable_trace_route=None, tcp_port=None, tcp_port_behavior=None, threshold_failed_percent=None, threshold_round_trip_time=None):
    '''
    Add a test configuration to a connection monitor
    '''
    return call_az("az network watcher connection-monitor test-configuration add", locals())


def remove(connection_monitor, location, name, test_groups=None):
    '''
    Remove a test configuration from a connection monitor
    '''
    return call_az("az network watcher connection-monitor test-configuration remove", locals())


def show(connection_monitor, location, name):
    '''
    Show a test configuration from a connection monitor
    '''
    return call_az("az network watcher connection-monitor test-configuration show", locals())


def list(connection_monitor, location):
    '''
    List all test configurations of a connection monitor
    '''
    return call_az("az network watcher connection-monitor test-configuration list", locals())




from ... pyaz_utils import call_az

def create(name, replication_role, resource_group, server_to_link):
    '''
    Adds a server link to the Redis cache (requires Premium SKU).
    '''
    return call_az("az redis server-link create", locals())


def delete(linked_server_name, name, resource_group):
    return call_az("az redis server-link delete", locals())


def show(linked_server_name, name, resource_group):
    return call_az("az redis server-link show", locals())


def list(name, resource_group):
    return call_az("az redis server-link list", locals())




from ... pyaz_utils import call_az

def show(name, resource_group=None):
    '''
    Get the login credentials for an Azure Container Registry.
    '''
    return call_az("az acr credential show", locals())


def renew(name, password_name, resource_group=None):
    '''
    Regenerate login credentials for an Azure Container Registry.
    '''
    return call_az("az acr credential renew", locals())




from ..... pyaz_utils import call_az

def create(name, resource_group, workspace_name, no_wait=None, resource_id=None, write_access_resource_id=None):
    '''
    Create a linked service.
    '''
    return call_az("az monitor log-analytics workspace linked-service create", locals())


def update(name, resource_group, workspace_name, add=None, force_string=None, no_wait=None, remove=None, resource_id=None, set=None, write_access_resource_id=None):
    '''
    Update a linked service.
    '''
    return call_az("az monitor log-analytics workspace linked-service update", locals())


def show(name, resource_group, workspace_name):
    '''
    Show the properties of a linked service.
    '''
    return call_az("az monitor log-analytics workspace linked-service show", locals())


def list(resource_group, workspace_name):
    '''
    Gets all the linked services in a workspace.
    '''
    return call_az("az monitor log-analytics workspace linked-service list", locals())


def delete(name, resource_group, workspace_name, no_wait=None, yes=None):
    '''
    Delete a linked service.
    '''
    return call_az("az monitor log-analytics workspace linked-service delete", locals())


def wait(name, resource_group, workspace_name, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the linked service is met.
    '''
    return call_az("az monitor log-analytics workspace linked-service wait", locals())




from ... pyaz_utils import call_az

def assign(name, identities=None, resource_group=None):
    '''
    Update managed identities for an App Configuration.
    '''
    return call_az("az appconfig identity assign", locals())


def remove(name, identities=None, resource_group=None):
    '''
    Remove managed identities for an App Configuration.
    '''
    return call_az("az appconfig identity remove", locals())


def show(name, resource_group=None):
    '''
    Display managed identities for an App Configuration.
    '''
    return call_az("az appconfig identity show", locals())




from ... pyaz_utils import call_az

def add(allowed_origins, name, resource_group, slot=None):
    '''
    Add allowed origins
    '''
    return call_az("az functionapp cors add", locals())


def remove(allowed_origins, name, resource_group, slot=None):
    '''
    Remove allowed origins
    '''
    return call_az("az functionapp cors remove", locals())


def show(name, resource_group, slot=None):
    '''
    show allowed origins
    '''
    return call_az("az functionapp cors show", locals())




from .. pyaz_utils import call_az

def list(resource_group=None):
    '''
    List container groups.
    '''
    return call_az("az container list", locals())


def create(resource_group, acr_identity=None, assign_identity=None, azure_file_volume_account_key=None, azure_file_volume_account_name=None, azure_file_volume_mount_path=None, azure_file_volume_share_name=None, command_line=None, cpu=None, dns_name_label=None, environment_variables=None, file=None, gitrepo_dir=None, gitrepo_mount_path=None, gitrepo_revision=None, gitrepo_url=None, image=None, ip_address=None, location=None, log_analytics_workspace=None, log_analytics_workspace_key=None, memory=None, name=None, no_wait=None, os_type=None, ports=None, protocol=None, registry_login_server=None, registry_password=None, registry_username=None, restart_policy=None, role=None, scope=None, secrets=None, secrets_mount_path=None, secure_environment_variables=None, subnet=None, subnet_address_prefix=None, vnet=None, vnet_address_prefix=None, vnet_name=None, zone=None):
    '''
    Create a container group.
    '''
    return call_az("az container create", locals())


def show(name, resource_group):
    '''
    Get the details of a container group.
    '''
    return call_az("az container show", locals())


def delete(name, resource_group, yes=None):
    '''
    Delete a container group.
    '''
    return call_az("az container delete", locals())


def logs(name, resource_group, container_name=None, follow=None):
    '''
    Examine the logs for a container in a container group.
    '''
    return call_az("az container logs", locals())


def exec(exec_command, name, resource_group, container_name=None):
    '''
    Execute a command from within a running container of a container group.
    '''
    return call_az("az container exec", locals())


def export(file, name, resource_group):
    '''
    Export a container group in yaml format.
    '''
    return call_az("az container export", locals())


def attach(name, resource_group, container_name=None):
    '''
    Attach local standard output and error streams to a container in a container group.
    '''
    return call_az("az container attach", locals())


def restart(name, resource_group, no_wait=None):
    return call_az("az container restart", locals())


def stop(name, resource_group):
    return call_az("az container stop", locals())


def start(name, resource_group, no_wait=None):
    return call_az("az container start", locals())




from .... pyaz_utils import call_az

def list(cluster, resource_group, workspace, expiry=None, path=None):
    '''
    List files generated by the cluster's node setup task.
    '''
    return call_az("az batchai cluster file list", locals())




from .. pyaz_utils import call_az

def on():
    '''
    Turn on local context
    '''
    return call_az("az local-context on", locals())


def off():
    '''
    Turn off local context
    '''
    return call_az("az local-context off", locals())


def show(name=None):
    '''
    Show local context data
    '''
    return call_az("az local-context show", locals())


def delete(all=None, name=None, purge=None, recursive=None, yes=None):
    '''
    Delete local context data
    '''
    return call_az("az local-context delete", locals())




from ... pyaz_utils import call_az

def list(billing_period_name=None, end_date=None, include_additional_properties=None, include_meter_details=None, start_date=None, top=None):
    '''
    List the details of Azure resource consumption, either as an invoice or within a billing period.
    '''
    return call_az("az consumption usage list", locals())




from .... pyaz_utils import call_az

def create(endpoints, key, name, value, resource_group=None):
    '''
    Create a message enrichment for chosen endpoints in your IoT Hub
    '''
    return call_az("az iot hub message-enrichment create", locals())


def list(name, resource_group=None):
    '''
    Get information on all message enrichments for your IoT Hub
    '''
    return call_az("az iot hub message-enrichment list", locals())


def delete(key, name, resource_group=None):
    '''
    Delete a message enrichment in your IoT hub (by key)
    '''
    return call_az("az iot hub message-enrichment delete", locals())


def update(endpoints, key, name, value, resource_group=None):
    '''
    Update a message enrichment in your IoT hub (by key)
    '''
    return call_az("az iot hub message-enrichment update", locals())




from .... pyaz_utils import call_az

def create(application, cluster_name, correlated_service_name, name, resource_group, scheme):
    '''
    Create a new managed service correlation scheme on an Azure Service Fabric managed cluster.
    '''
    return call_az("az sf managed-service correlation-scheme create", locals())


def update(application, cluster_name, correlated_service_name, name, resource_group, scheme):
    '''
    Update a managed service correlation scheme.
    '''
    return call_az("az sf managed-service correlation-scheme update", locals())


def delete(application, cluster_name, correlated_service_name, name, resource_group):
    '''
    Delete a managed service correlation scheme.
    '''
    return call_az("az sf managed-service correlation-scheme delete", locals())




from ..... pyaz_utils import call_az

def assign(identity, name, resource_group, no_wait=None):
    '''
    Assign a managed service identity to an ExpressRoute Port
    '''
    return call_az("az network express-route port identity assign", locals())


def remove(name, resource_group, no_wait=None):
    '''
    Remove the managed service identity of an ExpressRoute Port
    '''
    return call_az("az network express-route port identity remove", locals())


def show(name, resource_group):
    '''
    Show the managed service identity of an ExpressRoute Port
    '''
    return call_az("az network express-route port identity show", locals())




from ... pyaz_utils import call_az

def enable(disk_encryption_keyvault, name, resource_group, aad_client_cert_thumbprint=None, aad_client_id=None, aad_client_secret=None, encrypt_format_all=None, force=None, key_encryption_algorithm=None, key_encryption_key=None, key_encryption_keyvault=None, volume_type=None):
    '''
    Enable disk encryption on the OS disk and/or data disks. Encrypt mounted disks.
    '''
    return call_az("az vm encryption enable", locals())


def disable(name, resource_group, force=None, volume_type=None):
    '''
    Disable disk encryption on the OS disk and/or data disks. Decrypt mounted disks.
    '''
    return call_az("az vm encryption disable", locals())


def show(name, resource_group):
    '''
    Show encryption status.
    '''
    return call_az("az vm encryption show", locals())




from .. pyaz_utils import call_az
from . import action_group, activity_log, alert, autoscale, autoscale_settings, diagnostic_settings, log_profiles, metrics, private_link_scope


def clone(source_resource, target_resource, always_clone=None, types=None):
    '''
    Clone metrics alert rules from one resource to another resource.
    '''
    return call_az("az monitor clone", locals())




from .... pyaz_utils import call_az

def set(database, resource_group, server, status):
    '''
    Sets a database's transparent data encryption configuration.
    '''
    return call_az("az sql db tde set", locals())


def show(database, resource_group, server):
    return call_az("az sql db tde show", locals())


def list_activity(database, resource_group, server):
    return call_az("az sql db tde list-activity", locals())




from ... pyaz_utils import call_az

def add(nics, resource_group, vm_name, primary_nic=None):
    '''
    Add existing NICs to a VM.
    '''
    return call_az("az vm nic add", locals())


def remove(nics, resource_group, vm_name, primary_nic=None):
    '''
    Remove NICs from a VM.
    '''
    return call_az("az vm nic remove", locals())


def set(nics, resource_group, vm_name, primary_nic=None):
    '''
    Configure settings of a NIC attached to a VM.
    '''
    return call_az("az vm nic set", locals())


def show(nic, resource_group, vm_name):
    '''
    Display information for a NIC attached to a VM.
    '''
    return call_az("az vm nic show", locals())


def list(resource_group, vm_name):
    '''
    List the NICs available on a VM.
    '''
    return call_az("az vm nic list", locals())




from .... pyaz_utils import call_az

def show():
    '''
    Get deployment publishing user.
    '''
    return call_az("az webapp deployment user show", locals())


def set(user_name, password=None):
    '''
    Update deployment credentials.
    '''
    return call_az("az webapp deployment user set", locals())




from ... pyaz_utils import call_az
from . import action, condition


def show(profile_name, resource_group, rule_name, rule_set_name):
    '''
    Show delivery rule details.
    '''
    return call_az("az afd rule show", locals())


def list(profile_name, resource_group, rule_set_name):
    return call_az("az afd rule list", locals())


def create(action_name, order, profile_name, resource_group, rule_name, rule_set_name, cache_behavior=None, cache_duration=None, custom_fragment=None, custom_hostname=None, custom_path=None, custom_querystring=None, destination=None, header_action=None, header_name=None, header_value=None, match_processing_behavior=None, match_values=None, match_variable=None, negate_condition=None, operator=None, preserve_unmatched_path=None, query_parameters=None, query_string_behavior=None, redirect_protocol=None, redirect_type=None, selector=None, source_pattern=None, transform=None):
    '''
    Creates a new delivery rule within the specified rule set.
    '''
    return call_az("az afd rule create", locals())


def delete(profile_name, resource_group, rule_name, rule_set_name, yes=None):
    '''
    Remove a delivery rule from rule set.
    '''
    return call_az("az afd rule delete", locals())




from .... pyaz_utils import call_az

def add(capacity, cluster_name, node_type, resource_group, vm_password, vm_user_name, durability_level=None, vm_sku=None, vm_tier=None):
    '''
    Add a new node type to a cluster.
    '''
    return call_az("az sf cluster node-type add", locals())




from ... pyaz_utils import call_az
from . import key


def show(name, resource_group):
    '''
    Get the details of a topic.
    '''
    return call_az("az eventgrid topic show", locals())


def delete(name, resource_group):
    '''
    Delete a topic.
    '''
    return call_az("az eventgrid topic delete", locals())


def list(odata_query=None, resource_group=None):
    '''
    List available topics.
    '''
    return call_az("az eventgrid topic list", locals())


def create(name, resource_group, extended_location_name=None, extended_location_type=None, identity=None, inbound_ip_rules=None, input_mapping_default_values=None, input_mapping_fields=None, input_schema=None, kind=None, location=None, public_network_access=None, sku=None, tags=None):
    '''
    Create a topic.
    '''
    return call_az("az eventgrid topic create", locals())


def update(name, resource_group, identity=None, inbound_ip_rules=None, public_network_access=None, sku=None, tags=None):
    '''
    Update a topic.
    '''
    return call_az("az eventgrid topic update", locals())




from .... pyaz_utils import call_az

def show(account_name, resource_group):
    '''
    Get the data policy rules associated with the specified storage account.
    '''
    return call_az("az storage account management-policy show", locals())


def create(account_name, policy, resource_group):
    '''
    Create the data policy rules associated with the specified storage account.
    '''
    return call_az("az storage account management-policy create", locals())


def update(account_name, resource_group, add=None, force_string=None, remove=None, set=None):
    '''
    Update the data policy rules associated with the specified storage account.
    '''
    return call_az("az storage account management-policy update", locals())


def delete(account_name, resource_group):
    '''
    Delete the data policy rules associated with the specified storage account.
    '''
    return call_az("az storage account management-policy delete", locals())




from .... pyaz_utils import call_az

def list(database, resource_group, server):
    return call_az("az sql db op list", locals())


def cancel(database, name, resource_group, server):
    return call_az("az sql db op cancel", locals())




from .... pyaz_utils import call_az

def list(account_endpoint=None, account_key=None, account_name=None, end_time=None, filter=None, start_time=None):
    return call_az("az batch pool usage-metrics list", locals())




from ... pyaz_utils import call_az

def create(resource_group, workspace, location=None):
    '''
    Create a workspace.
    '''
    return call_az("az batchai workspace create", locals())


def show(resource_group, workspace):
    '''
    Show information about a workspace.
    '''
    return call_az("az batchai workspace show", locals())


def list(resource_group=None):
    '''
    List workspaces.
    '''
    return call_az("az batchai workspace list", locals())


def delete(resource_group, workspace, no_wait=None, yes=None):
    '''
    Delete a workspace.
    '''
    return call_az("az batchai workspace delete", locals())




from .... pyaz_utils import call_az

def show(account, recurrence_identity, end_date_time=None, start_date_time=None):
    '''
    Retrieve a job recurrence in a Data Lake Analytics account.
    '''
    return call_az("az dla job recurrence show", locals())


def list(account, end_date_time=None, start_date_time=None):
    '''
    List job recurrences in a Data Lake Analytics account.
    '''
    return call_az("az dla job recurrence list", locals())




from .... pyaz_utils import call_az

def create(endpoint_name, endpoint_resource_group, endpoint_subscription_id, endpoint_type, hub_name, auth_type=None, batch_frequency=None, chunk_size=None, connection_string=None, container_name=None, encoding=None, endpoint_uri=None, entity_path=None, file_name_format=None, identity=None, resource_group=None):
    '''
    Add an endpoint to your IoT Hub.
    '''
    return call_az("az iot hub routing-endpoint create", locals())


def show(endpoint_name, hub_name, resource_group=None):
    '''
    Get information on mentioned endpoint for your IoT Hub.
    '''
    return call_az("az iot hub routing-endpoint show", locals())


def list(hub_name, endpoint_type=None, resource_group=None):
    '''
    Get information on all the endpoints for your IoT Hub.
    '''
    return call_az("az iot hub routing-endpoint list", locals())


def delete(hub_name, endpoint_name=None, endpoint_type=None, resource_group=None):
    '''
    Delete all or mentioned endpoint for your IoT Hub.
    '''
    return call_az("az iot hub routing-endpoint delete", locals())




from ... pyaz_utils import call_az

def create(name, resource_group, server, backup_storage_redundancy=None, collation=None, max_size=None, no_wait=None, service_objective=None, tags=None, zone_redundant=None):
    '''
    Create a data warehouse.
    '''
    return call_az("az sql dw create", locals())


def show(name, resource_group, server):
    '''
    Get the details for a data warehouse.
    '''
    return call_az("az sql dw show", locals())


def list(resource_group, server):
    '''
    List data warehouses for a server.
    '''
    return call_az("az sql dw list", locals())


def delete(name, resource_group, server, no_wait=None, yes=None):
    '''
    Delete a data warehouse.
    '''
    return call_az("az sql dw delete", locals())


def pause(name, resource_group, server):
    return call_az("az sql dw pause", locals())


def resume(name, resource_group, server):
    return call_az("az sql dw resume", locals())


def update(name, resource_group, server, add=None, force_string=None, max_size=None, no_wait=None, remove=None, service_objective=None, set=None):
    '''
    Update a data warehouse.
    '''
    return call_az("az sql dw update", locals())




from .... pyaz_utils import call_az

def create(name, resource_group, workspace_name, compute_type=None, core_count=None, description=None, if_match=None, location=None, no_wait=None, time_to_live=None):
    '''
    Create an managed integration runtime.
    '''
    return call_az("az synapse integration-runtime managed create", locals())




from ... pyaz_utils import call_az
from . import member, owner


def delete(group):
    return call_az("az ad group delete", locals())


def show(group):
    return call_az("az ad group show", locals())


def get_member_groups(group, additional_properties=None, security_enabled_only=None):
    return call_az("az ad group get-member-groups", locals())


def list(display_name=None, filter=None):
    return call_az("az ad group list", locals())


def create(display_name, mail_nickname, description=None, force=None):
    '''
    Create a group in the directory.
    '''
    return call_az("az ad group create", locals())




from ..... pyaz_utils import call_az
from . import match_condition


def create(action, name, policy_name, priority, resource_group, rule_type):
    '''
    Create an application gateway WAF policy custom rule.
    '''
    return call_az("az network application-gateway waf-policy custom-rule create", locals())


def delete(name, policy_name, resource_group):
    '''
    Delete an application gateway WAF policy custom rule.
    '''
    return call_az("az network application-gateway waf-policy custom-rule delete", locals())


def list(policy_name, resource_group):
    '''
    List application gateway WAF policy custom rules.
    '''
    return call_az("az network application-gateway waf-policy custom-rule list", locals())


def show(name, policy_name, resource_group):
    '''
    Get the details of an application gateway WAF policy custom rule.
    '''
    return call_az("az network application-gateway waf-policy custom-rule show", locals())


def update(name, policy_name, resource_group, action=None, add=None, force_string=None, priority=None, remove=None, rule_type=None, set=None):
    '''
    Update an application gateway WAF policy custom rule.
    '''
    return call_az("az network application-gateway waf-policy custom-rule update", locals())




from .... pyaz_utils import call_az

def regenerate(key_name, name, resource_group):
    '''
    Manage Azure Cognitive Services accounts.
    '''
    return call_az("az cognitiveservices account keys regenerate", locals())


def list(name, resource_group):
    '''
    Manage Azure Cognitive Services accounts.
    '''
    return call_az("az cognitiveservices account keys list", locals())




from ... pyaz_utils import call_az

def list(artifact_source_name, lab_name, resource_group, expand=None, filter=None, orderby=None, top=None):
    return call_az("az lab arm-template list", locals())


def show(artifact_source_name, lab_name, name, resource_group, export_parameters=None):
    '''
    Get the details of an ARM template in a lab.
    '''
    return call_az("az lab arm-template show", locals())




from ... pyaz_utils import call_az

def list(name, resource_group=None):
    '''
    List app settings of the static app.
    '''
    return call_az("az staticwebapp appsettings list", locals())


def set(name, setting_names, resource_group=None):
    '''
    Add to or change the app settings of the static app.
    '''
    return call_az("az staticwebapp appsettings set", locals())


def delete(name, setting_names, resource_group=None):
    '''
    Delete app settings with given keys of the static app.
    '''
    return call_az("az staticwebapp appsettings delete", locals())




from .... pyaz_utils import call_az

def set(function_name, key_name, name, resource_group, key_value=None, slot=None):
    '''
    Create or update a function key.
    '''
    return call_az("az functionapp function keys set", locals())


def list(function_name, name, resource_group, slot=None):
    '''
    List all function keys.
    '''
    return call_az("az functionapp function keys list", locals())


def delete(key_name, name, resource_group, function_name=None, slot=None):
    '''
    Delete a function key.
    '''
    return call_az("az functionapp function keys delete", locals())




from .... pyaz_utils import call_az

def tail(name, resource_group, aggregation=None, dimension=None, end_time=None, filter=None, interval=None, metadata=None, metrics=None, namespace=None, offset=None, orderby=None, start_time=None, top=None):
    '''
    List the metric values for a VM.
    '''
    return call_az("az vm monitor metrics tail", locals())


def list_definitions(name, resource_group, namespace=None):
    '''
    List the metric definitions for a VM.
    '''
    return call_az("az vm monitor metrics list-definitions", locals())




from ..... pyaz_utils import call_az

def set(action, duration, name, policy_name, priority, request_threshold, resource_group, disabled=None):
    '''
    Add a rate limit rule to a CDN WAF policy.
    '''
    return call_az("az cdn waf policy rate-limit-rule set", locals())


def delete(name, policy_name, resource_group, yes=None):
    '''
    Remove a rate limit rule from a CDN WAF policy.
    '''
    return call_az("az cdn waf policy rate-limit-rule delete", locals())


def list(policy_name, resource_group):
    '''
    List rate limit rules of a CDN WAF policy.
    '''
    return call_az("az cdn waf policy rate-limit-rule list", locals())


def show(name, policy_name, resource_group):
    '''
    Show a rate limit rule of a CDN WAF policy.
    '''
    return call_az("az cdn waf policy rate-limit-rule show", locals())




from .... pyaz_utils import call_az

def list(name, resource_group):
    '''
    List all read replicas for a given server.
    '''
    return call_az("az mysql flexible-server replica list", locals())


def create(replica_name, resource_group, source_server, no_wait=None, zone=None):
    '''
    Create a read replica for a server.
    '''
    return call_az("az mysql flexible-server replica create", locals())


def stop_replication(name, resource_group, yes=None):
    '''
    Stop replication to a read replica and make it a read/write server.
    '''
    return call_az("az mysql flexible-server replica stop-replication", locals())




from ..... pyaz_utils import call_az

def update(metadata, name, account_key=None, account_name=None, auth_mode=None, connection_string=None, sas_token=None, timeout=None):
    return call_az("az storage fs directory metadata update", locals())


def show(name, account_key=None, account_name=None, auth_mode=None, connection_string=None, sas_token=None, timeout=None):
    '''
    Return all user-defined metadata for the specified directory.
    '''
    return call_az("az storage fs directory metadata show", locals())




from .... pyaz_utils import call_az

def list(gateway_name, resource_group):
    '''
    List HTTP settings.
    '''
    return call_az("az network application-gateway http-settings list", locals())


def show(gateway_name, name, resource_group):
    '''
    Get the details of a gateway's HTTP settings.
    '''
    return call_az("az network application-gateway http-settings show", locals())


def delete(gateway_name, name, resource_group, no_wait=None):
    '''
    Delete HTTP settings.
    '''
    return call_az("az network application-gateway http-settings delete", locals())


def create(gateway_name, name, port, resource_group, affinity_cookie_name=None, auth_certs=None, connection_draining_timeout=None, cookie_based_affinity=None, enable_probe=None, host_name=None, host_name_from_backend_pool=None, no_wait=None, path=None, probe=None, protocol=None, root_certs=None, timeout=None):
    '''
    Create HTTP settings.
    '''
    return call_az("az network application-gateway http-settings create", locals())


def update(gateway_name, name, resource_group, add=None, affinity_cookie_name=None, auth_certs=None, connection_draining_timeout=None, cookie_based_affinity=None, enable_probe=None, force_string=None, host_name=None, host_name_from_backend_pool=None, no_wait=None, path=None, port=None, probe=None, protocol=None, remove=None, root_certs=None, set=None, timeout=None):
    '''
    Update HTTP settings.
    '''
    return call_az("az network application-gateway http-settings update", locals())




from .... pyaz_utils import call_az

def list(gateway_name, resource_group):
    '''
    List SSL certificates.
    '''
    return call_az("az network application-gateway ssl-cert list", locals())


def show(gateway_name, name, resource_group):
    '''
    Get the details of an SSL certificate.
    '''
    return call_az("az network application-gateway ssl-cert show", locals())


def delete(gateway_name, name, resource_group, no_wait=None):
    '''
    Delete an SSL certificate.
    '''
    return call_az("az network application-gateway ssl-cert delete", locals())


def create(gateway_name, name, resource_group, cert_file=None, cert_password=None, key_vault_secret_id=None, no_wait=None):
    '''
    Upload an SSL certificate.
    '''
    return call_az("az network application-gateway ssl-cert create", locals())


def update(gateway_name, name, resource_group, add=None, cert_file=None, cert_password=None, force_string=None, key_vault_secret_id=None, no_wait=None, remove=None, set=None):
    '''
    Update an SSL certificate.
    '''
    return call_az("az network application-gateway ssl-cert update", locals())




from ... pyaz_utils import call_az

def invoke(command_id, instance_id, name, resource_group, parameters=None, scripts=None):
    '''
    Execute a specific run command on a Virtual Machine Scale Set instance.
    '''
    return call_az("az vmss run-command invoke", locals())


def list(instance_id, resource_group, vmss_name, expand=None):
    '''
    The operation to get all run commands of an instance in Virtual Machine Scaleset.
    '''
    return call_az("az vmss run-command list", locals())


def show(instance_id, name, resource_group, vmss_name, expand=None, instance_view=None):
    '''
    The operation to get the VMSS run command.
    '''
    return call_az("az vmss run-command show", locals())


def create(instance_id, name, resource_group, vmss_name, async_execution=None, command_id=None, error_blob_uri=None, location=None, no_wait=None, output_blob_uri=None, parameters=None, protected_parameters=None, run_as_password=None, run_as_user=None, script=None, script_uri=None, tags=None, timeout_in_seconds=None):
    '''
    The operation to Create the VMSS VM run command.
    '''
    return call_az("az vmss run-command create", locals())


def update(instance_id, name, resource_group, vmss_name, async_execution=None, command_id=None, error_blob_uri=None, location=None, no_wait=None, output_blob_uri=None, parameters=None, protected_parameters=None, run_as_password=None, run_as_user=None, script=None, script_uri=None, tags=None, timeout_in_seconds=None):
    '''
    The operation to update the VMSS run command.
    '''
    return call_az("az vmss run-command update", locals())


def delete(instance_id, name, resource_group, vmss_name, no_wait=None, yes=None):
    '''
    The operation to delete the run command.
    '''
    return call_az("az vmss run-command delete", locals())




from ... pyaz_utils import call_az

def show(container_name, name, resource_group, vault_name, backup_management_type=None, use_secondary_region=None, workload_type=None):
    '''
    Show details of a particular backed up item.
    '''
    return call_az("az backup item show", locals())


def list(resource_group, vault_name, backup_management_type=None, container_name=None, use_secondary_region=None, workload_type=None):
    '''
    List all backed up items within a container.
    '''
    return call_az("az backup item list", locals())


def set_policy(container_name, name, policy_name, resource_group, vault_name, backup_management_type=None, workload_type=None):
    '''
    Update the policy associated with this item. Use this to change policies of the backup item.
    '''
    return call_az("az backup item set-policy", locals())




from .... pyaz_utils import call_az

def create(resource_group, server_name, charset=None, collation=None, database_name=None):
    '''
    Create a MySQL database on a flexible server.
    '''
    return call_az("az mysql flexible-server db create", locals())


def delete(database_name=None, resource_group=None, server_name=None, yes=None):
    '''
    Delete a database on a flexible server.
    '''
    return call_az("az mysql flexible-server db delete", locals())


def show(database_name, resource_group, server_name):
    '''
    Show the details of a database.
    '''
    return call_az("az mysql flexible-server db show", locals())


def list(resource_group, server_name):
    '''
    List the databases for a flexible server.
    '''
    return call_az("az mysql flexible-server db list", locals())




from ... pyaz_utils import call_az

def invoke(name, resource_group, command=None, file=None, no_wait=None):
    '''
    Run a shell command (with kubectl, helm) on your aks cluster, support attaching files as well.
    '''
    return call_az("az aks command invoke", locals())


def result(name, resource_group, command_id=None):
    '''
    Fetch result from previously triggered 'aks command invoke'.
    '''
    return call_az("az aks command result", locals())




from .... pyaz_utils import call_az

def add(name, repo, resource_group, branch=None, force=None, login_with_github=None, runtime=None, slot=None, token=None):
    '''
    Add a GitHub Actions workflow file to the specified repository. The workflow will build and deploy your app to the specified webapp.
    '''
    return call_az("az webapp deployment github-actions add", locals())


def remove(name, repo, resource_group, branch=None, login_with_github=None, slot=None, token=None):
    '''
    Remove and disconnect the GitHub Actions workflow file from the specified repository.
    '''
    return call_az("az webapp deployment github-actions remove", locals())




from .... pyaz_utils import call_az

def add(cluster_name, resource_group, common_name=None, is_admin=None, issuer_thumbprint=None, thumbprint=None):
    '''
    Add a new client certificate to the managed cluster.
    '''
    return call_az("az sf managed-cluster client-certificate add", locals())


def delete(cluster_name, resource_group, common_name=None, thumbprint=None):
    '''
    Delete a client certificate from the managed cluster.
    '''
    return call_az("az sf managed-cluster client-certificate delete", locals())




from ..... pyaz_utils import call_az

def set(action, name, policy_name, priority, resource_group, disabled=None):
    '''
    Add a custom rule to a CDN WAF policy.
    '''
    return call_az("az cdn waf policy custom-rule set", locals())


def delete(name, policy_name, resource_group, yes=None):
    '''
    Remove a custom rule from a CDN WAF policy.
    '''
    return call_az("az cdn waf policy custom-rule delete", locals())


def list(policy_name, resource_group):
    '''
    List custom rules of a CDN WAF policy.
    '''
    return call_az("az cdn waf policy custom-rule list", locals())


def show(name, policy_name, resource_group):
    '''
    Show a custom rule of a CDN WAF policy.
    '''
    return call_az("az cdn waf policy custom-rule show", locals())




from ... pyaz_utils import call_az
from . import group


def show(host_group, name, resource_group):
    '''
    Get the details of a dedicated host.
    '''
    return call_az("az vm host show", locals())


def get_instance_view(host_group, name, resource_group):
    '''
    Get instance information about a dedicated host.
    '''
    return call_az("az vm host get-instance-view", locals())


def create(host_group, name, resource_group, sku, auto_replace=None, license_type=None, location=None, platform_fault_domain=None, tags=None):
    '''
    Create a dedicated host.
    '''
    return call_az("az vm host create", locals())


def list(host_group, resource_group):
    '''
    List dedicated hosts.
    '''
    return call_az("az vm host list", locals())


def update(host_group, name, resource_group, add=None, force_string=None, remove=None, set=None):
    '''
    Update a dedicated host.
    '''
    return call_az("az vm host update", locals())


def delete(host_group, name, resource_group, yes=None):
    return call_az("az vm host delete", locals())

